@@ -15,6 +15,18 @@
 // Revised: 10/2/2015	ELL
 // Modified to get template from field in page data record instead of parsing page file.
 // Modified to get border area names and head name from fields in page data record instead of parsing page file.
+// Revised: 5/26/2016	ELL
+// Added function string checking to standardize entry of function call.
+// Added simultaneous deployment of mobile styles for plugin if provided.
+// Revised: 6/11/2016	ELL
+// Modified template minimum requirements checking to include header and footer.
+// Added simultaneous deployment of mobile styles for plugin if provided.
+// Revised: 8/15/2016	ELL
+// Added ability to adapt script and css folders in head HTML to config file settings.
+// Revised: 11/11/2016	ELL
+// Implemented new plugin field custom_css_sql.
+// Revised: 6/19/2017	ELL
+// Moved 'deployed' field to new table plugins_deployed.
 // 
 
 include ("check_session.php");
@@ -25,7 +37,7 @@ $plugin = $_POST['plugin'];
 include("lib/run_sql.php");
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
-function copy_table_structure($table, $table_prefix, $dbh, $database)
+function copy_table_structure($table, $table_prefix, $dbh, $database, $source_table = "", $copy_data = false)
 {
 	$query = "SELECT COUNT(*) FROM information_schema.tables WHERE table_schema = '" . $database . "' AND table_name = '" . $table_prefix . $table . "'";
 	$result = $dbh->query($query);
@@ -34,13 +46,21 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 	if ($table_count < 1)
 	{
 		// Must be a missing menu table, find suffix.
-		if (strpos($table, "_classes") > 0)
-			$source_table = $table_prefix . "site_classes";
+		if ($source_table == "")	{
+			if (strpos($table, "_classes") > 0)
+				$source_table = $table_prefix . "site_classes";
+			else
+				$source_table = $table_prefix . "site_css";
+		}
 		else
-			$source_table = $table_prefix . "site_css";
+			$source_table = $table_prefix . $source_table;
 
 		$query = "CREATE TABLE " . $table_prefix . $table . " LIKE " . $source_table;
 		$cnt = $dbh->exec($query);
+		if ($copy_data === true)	{
+			$query = "INSERT " . $table_prefix . $table . " SELECT * FROM " . $source_table;
+			$cnt = $dbh->exec($query);
+		}
 	}
 		
 	return 1;
@@ -79,10 +99,31 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 	$style_sheet_description = $row["style_sheet_description"];
 	$class_sql = $row["class_sql"];
 	$css_sql = $row["css_sql"];
+	$custom_css_sql = $row["custom_css_sql"];
 	$plugin_sql = $row["plugin_sql"];
-	$deployed = $row["deployed"];
 	$body_onload = $row["body_onload"];
-	$body_onload_function = (isset($row["body_onload_function"]) ? $row["body_onload_function"] : $page_name . "_load");
+	if (isset($row["body_onload_function"]) && ($row["body_onload_function"] != ""))	{
+		$body_onload_function = $row["body_onload_function"];
+		$funct_str_len = strlen($body_onload_function);
+		$funct_str_end = substr($body_onload_function, $funct_str_len - 3);
+		if (strpos($funct_str_end, "();") === false)	{
+			if (strpos($funct_str_end, ")") == 2)
+				$body_onload_function .= ";";
+			elseif (strpos($funct_str_end, ");") != 1)
+				$body_onload_function .= "();";
+		}
+	}
+	else
+		$body_onload_function = $page_name . "_load();";
+		
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE `plugin_id` = $plugin";
+	$result = $bwb_dbh->query($query);
+	if ($result->rowCount() > 0)	{
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$deployed = $row["deployed"];
+	}
+	else
+		$deployed = 0;
 	
 	//Get page content from database.
 	$today = date("Y-m-d H:i:s");
@@ -285,6 +326,44 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$new = true;
 		}
 		
+		// Adjust path to any JavaScript includes, CSS, images, Flash or media to settings in config file.
+		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))	{
+			$scripts_dir_rel = BWB_SCRIPTS_DIR . "/";
+			$flash_dir_rel = BWB_FLASH_DIR . "/";
+			$media_dir_rel = BWB_MEDIA_DIR . "/";
+			$image_dir_rel = BWB_IMAGE_DIR . "/";
+			$css_dir_rel = BWB_CSS_DIR . "/";
+		}
+		elseif ((BWB_BASE_DIR == '') || (BWB_WEBPAGE_DIR == ''))
+		{
+			if (BWB_BASE_DIR == '')	{
+				$scripts_dir_rel = "../" . BWB_SCRIPTS_DIR . "/";
+				$flash_dir_rel = "../" . BWB_FLASH_DIR . "/";
+				$media_dir_rel = "../" . BWB_MEDIA_DIR . "/";
+				$image_dir_rel = "../" .BWB_IMAGE_DIR . "/";
+				$css_dir_rel = "../" . BWB_CSS_DIR . "/";
+			}
+			elseif (BWB_WEBPAGE_DIR == '')	{
+				$scripts_dir_rel = BWB_SCRIPTS_DIR . "/";
+				$flash_dir_rel = BWB_FLASH_DIR . "/";
+				$media_dir_rel = BWB_MEDIA_DIR . "/";
+				$image_dir_rel = BWB_IMAGE_DIR . "/";
+				$css_dir_rel = BWB_CSS_DIR . "/";
+			}
+		}
+		else	{
+			$scripts_dir_rel = "../" . BWB_SCRIPTS_DIR . "/";
+			$flash_dir_rel = "../" . BWB_FLASH_DIR . "/";
+			$media_dir_rel = "../" . BWB_MEDIA_DIR . "/";
+			$image_dir_rel = "../" .BWB_IMAGE_DIR . "/";
+			$css_dir_rel = "../" . BWB_CSS_DIR . "/";
+		}
+		$head_html = str_replace("scripts/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("css/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("images/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("media/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("flash/", $scripts_dir_rel, $head_html);
+		
 		// Combine HTML (Javascript) code with default head content.
 		$head_content = $head_content . "\n\n\n" . $head_html;
 		$head_content = addslashes(stripslashes($head_content));
@@ -523,26 +602,39 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 				$row = $result->fetch(PDO::FETCH_ASSOC);
 				$sort_order = $row['sort_order'] + 10;
 				
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order;
+				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				 	$show_custom_styles = 1;
+				else
+					$show_custom_styles = 0;
+				
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_mobile', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
 			}
 		}
 		
 		if (isset($class_sql) && ($class_sql != ""))
 		{
-			$class_table = $style_sheet . "_classes";
-			copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 			$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
 		if (isset($css_sql) && ($css_sql != ""))
 		{
-			$site_css_table = $style_sheet . "_css";
-			copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 			$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
-			
+		}
+				
+		if (isset($custom_css_sql) && ($custom_css_sql != ""))
+		{
+			$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+		}
+		
+		if ((isset($css_sql) && ($css_sql != "")) || (isset($custom_css_sql) && ($custom_css_sql != "")))
+		{	
 			include ("lib/build_css_string.php");
-			$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
+			$css_string = BuildCSSString($style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
 			////////////////////////////////////////////////////////
 			/// Write menu items to menu.css file /////////////
 			//Test to see if file already exists.
@@ -567,6 +659,27 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$result = (fputs($fh, $css_string));
 			fclose($fh) or die($php_errormsg);
 			@chmod($file_name, 0644);
+			
+			/////////////////////////////////////////////////////
+			// Build mobile style sheet
+			$css_string = BuildCSSString($style_sheet . "_mobile", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+			
+			$css_file = $style_sheet . "_mobile.css";
+			$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+				
+			if (file_exists($file_name))
+			{
+				$bkup_file_name = $file_name . time();
+				if (!rename($file_name, $bkup_file_name))
+					echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+				@chmod($bkup_file_name, 0644);
+			}
+			
+			// Create file.
+			$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+			$result = (fputs($fh, $css_string));
+			fclose($fh) or die($php_errormsg);
+			@chmod($file_name, 0644);
 		}
 		
 		if (isset($plugin_sql) && ($plugin_sql != ""))
@@ -574,9 +687,108 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 		
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=1 WHERE `id`=$plugin";
+		$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
 		$cnt = $bwb_dbh->exec($query);
-	}	
+	}
+	
+	///////////////////////////////////////////////////////////////
+	// Change page-template layout if needed.
+	$query = "SELECT template FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name = '" . $page_name . "'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$template_name = $row['template'];
+	
+	// Check template compatibility with plugin.
+	if (strpos($template_name, "header_footer_top_bottom_left_right") === false)
+	{
+		$need_header = false;
+		$need_footer = false;
+		$need_top = false;
+		$need_left = false;
+		$need_right = false;
+		$need_bottom = false;
+		$need_alt = false;
+		$need_alt2 = false;
+		$dont_want_header = false;
+		$dont_want_footer = false;
+		$dont_want_top = false;
+		$dont_want_left = false;
+		$dont_want_right = false;
+		$dont_want_bottom = false;
+		
+		if ((isset($header_code) && ($header_code != "")) || (isset($header_html) && ($header_html != "")) && (strpos($template_name, "header") === false))
+			$need_header = true;
+		if ((isset($footer_code) && ($footer_code != "")) || (isset($footer_html) && ($footer_html != "")) && (strpos($template_name, "footer") === false))
+			$need_footer = true;
+		if ((isset($top_code) && ($top_code != "")) || (isset($top_html) && ($top_html != "")) && (strpos($template_name, "top") === false))
+			$need_top = true;
+		if ((isset($left_code) && ($left_code != "")) || (isset($left_html) && ($left_html != "")) && (strpos($template_name, "left") === false))
+			$need_left = true;
+		if ((isset($right_code) && ($right_code != "")) || (isset($right_html) && ($right_html != "")) && (strpos($template_name, "right") === false))
+			$need_right = true;
+		if ((isset($bottom_code) && ($bottom_code != "")) || (isset($bottom_html) && ($bottom_html != "")) && (strpos($template_name, "bottom") === false))
+			$need_bottom = true;
+			
+		if (strpos($template_name, "header") === false)
+			$dont_want_header = true;
+		if (strpos($template_name, "footer") === false)
+			$dont_want_footer = true;
+		if (strpos($template_name, "top") === false)
+			$dont_want_top = true;
+		if (strpos($template_name, "left") === false)
+			$dont_want_left = true;
+		if (strpos($template_name, "right") === false)
+			$dont_want_right = true;
+		if (strpos($template_name, "bottom") === false)
+			$dont_want_bottom = true;
+			
+		if (strpos($template_name, "alt2") !== false)
+			$need_alt2 = true;
+		elseif (strpos($template_name, "alt") !== false)
+			$need_alt = true;
+			
+		if (($need_header === true) || ($need_footer === true) || ($need_top === true) || ($need_left === true) || ($need_right === true) || ($need_bottom === true))
+		{
+			$where = "";
+			if ($need_header === true)
+				$where .= " AND option_value LIKE '%header%'";
+			elseif (($dont_want_header === true) && ($need_footer !== true))
+				$where .= " AND option_value NOT LIKE '%header%'";
+			if ($need_footer === true)
+				$where .= " AND option_value LIKE '%footer%'";
+			elseif ($dont_want_footer === true)
+				$where .= " AND option_value NOT LIKE '%footer%'";
+			if ($need_top === true)
+				$where .= " AND option_value LIKE '%top%'";
+			elseif (($dont_want_top === true) && ($need_bottom !== true))
+				$where .= " AND option_value NOT LIKE '%top%'";
+			if ($need_left === true)
+				$where .= " AND option_value LIKE '%left%'";
+			elseif (($dont_want_left === true) && ($need_right !== true))
+				$where .= " AND option_value NOT LIKE '%left%'";
+			if ($need_right === true)
+				$where .= " AND option_value LIKE '%right%'";
+			elseif ($dont_want_right === true)
+				$where .= " AND option_value NOT LIKE '%right%'";
+			if ($need_bottom === true)
+				$where .= " AND option_value LIKE '%bottom%'";
+			elseif ($dont_want_bottom === true)
+				$where .= " AND option_value NOT LIKE '%bottom%'";
+				
+			if ($need_alt2 === true)
+				$where .= " AND option_value LIKE '%alt2%'";
+			elseif ($need_alt === true)
+				$where .= " AND option_value LIKE '%alt%' AND NOT LIKE '%alt2%'";
+				
+			$query = "SELECT option_value FROM " . BWB_TABLE_PREFIX . "options WHERE option_name = 'Template'" . $where . " ORDER BY dropdown_sort_order";
+			$result = $bwb_dbh->query($query);
+			$row = $result->fetch(PDO::FETCH_ASSOC);
+			$template_name = $row['option_value'];
+			
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET template = '" . $template_name . "' WHERE page_name = '" . $page_name . "'";
+			$cnt = $bwb_dbh->exec($query);
+		}
+	}
 	
 	//Go to edit page.
 	$domain = $_SERVER['HTTP_HOST'];
