@@ -8,12 +8,25 @@
 // Added Generate Site Map button.
 // Revised: 4/12/2016	ELL
 // Added ids to buttons to provide click control from main menu.
+// Revised: 5/27/2016	ELL
+// Added lockout of Clear All Custom CSS.
+// Revised: 5/1/2017	ELL
+// Added button for restricting blogging pages to bloggers.
+// Revised: 6/19/2017	ELL
+// Moved 'deployed' field to new table plugins_deployed.
 // 
 
 	include ("check_session.php");
 	
+	if ($access_level != "admin")
+		exit;
+	
 	$display_pruned_bkup_files_msg = $_REQUEST['display_pruned_bkup_files_msg'];
 	
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name` = 'LockoutClearAllCustomCSSClasses'";
+	$result = $bwb_dbh->query($query);
+	$row = $result->fetch(PDO::FETCH_ASSOC);
+	$LockoutClearAllCustomCSSClasses = $row['option_value'];
 ?>
 <!DOCTYPE html>
 <html>
@@ -70,7 +83,7 @@ function ActivateDeactivateConfirm()
 	popup_msg.popup_button_2_span = "Yes";
 	popup_msg.popup_button_1_span = "No";
 	popup_msg.popup_timeout = -1;
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 
 <?php
 	$document_root = getenv('DOCUMENT_ROOT');
@@ -107,11 +120,14 @@ function ActivateDeactivateConfirm()
     
 	<div class='button_sub_level_1' id='btn_users' onClick="window.location='users.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN; ?></span></div>
     <div class='button_sub_level_1' id='btn_site_options' onClick="window.location='options.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN; ?></span></div>
-    <div class='button_sub_level_1' id='btn_restrict_editing_access' onClick="window.location='restrict_editing_access.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN; ?></span></div>
+    <div class='button_sub_level_1' id='btn_restrict_editing_access' onClick="window.location='restrict_editing_access.php?AccessLevel=restricted';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN; ?></span></div>
+    <div class='button_sub_level_1' id='btn_restrict_editing_access' onClick="window.location='restrict_editing_access.php?AccessLevel=blogger';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN; ?></span></div>
     <div class='button_sub_level_1' id='btn_generate_site_map' onClick="window.location='generate_site_map_shell.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN; ?></span></div>
     <div class='button_sub_level_1' id='btn_prune_page_edit_bkup_tbl' onClick="ShowPrunePageEditBkupTable();"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN; ?></span></div>
 	<div class='button_console' id="btn_prune_css" onClick="window.location='prune_bkup_files.php';"><span class='button_console_text'><?php echo ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN; ?></span></div>
+<?php if ($LockoutClearAllCustomCSSClasses != 1)	{	?>
     <div class='button_sub_level_1' id='btn_delete_custom_classes' onClick="window.location='delete_custom_classes_select.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_CLEAR_CUSTOM_CLASSES_BTN; ?></span></div>
+<?php }	?>
 	<div class='button_sub_level_1' id='btn_upload_plugin' onClick="window.location='upload_plugin.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_INSTALL_PLUGIN_BTN; ?></span></div>
 	<div class='button_sub_level_1' id='btn_show_recall_plugin' onClick="ShowRecallPlugin();"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_RECALL_PLUGIN_BTN; ?></span></div>
 	<div class='button_sub_level_1' id='btn_upload_update' onClick="window.location='upload_update.php';"><span class='button_text_sub_level_1'><?php echo ADMIN_FUNCTION_SELECT_INSTALL_UPDATE_BTN; ?></span></div>
@@ -135,7 +151,7 @@ function ActivateDeactivateConfirm()
   <?php echo ADMIN_FUNCTION_SELECT_SELECT_PLUGIN_TO_RECALL; ?>:<br />
   	<select name="recall_plugin" id="recall_plugin" style="width:400px;">
 <?php
-	$query = "SELECT `id`, `name`, `description` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `deployed`=1 ORDER BY `sort_order`";
+	$query = "SELECT T1.id, T1.name, T1.description FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T2.deployed=1 ORDER BY T1.sort_order";
 	$result = $bwb_dbh->query($query);
 	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
@@ -156,7 +172,7 @@ function ActivateDeactivateConfirm()
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="JavaScript"  type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 <?php	if ($display_pruned_bkup_files_msg == 1)	{	?>
 	popup_msg.top_offset = 100;
 	popup_msg.left_offset = 320;
