@@ -1,5 +1,5 @@
 <?php
-// Reset Password, copyright 2012, EB Dynamics, Inc., Ed Lemmers
+// Reset Password, copyright 2012-2018, Silver Dolphin Solutions, LLC, Ed Lemmers
 // For licensing, see license.txt.
 // Revised 9/10/2014	BAK
 // Added link back to website to a page as denfined by the 'email_link_page' hidden field.
@@ -16,8 +16,21 @@ $referers = array($server_name_www, $server_name);
 // Module for performaing actual email operation.
 include("mime_mail.inc");
 // DB connection for retrieving HTML message format for message back to inquirer, etc.
-include("../connect/db_connect.php");
-include("../connect/config.php");
+$doc_root = $_SERVER['DOCUMENT_ROOT'];
+if (file_exists("../connect/config.php"))	// Default installation
+	$connect_path = "../connect/";
+elseif (file_exists($doc_root . "/connect/config.php"))	// Custom userfile folders
+	$connect_path = $doc_root . "/connect/";
+else	{	// Must be installeed in sub domain or sub folder with non-standard userfile folders.
+	$php_self = $_SERVER["PHP_SELF"];
+	$self_parts = explode('/', $php_self);
+	$this_script = $self_parts[count($self_parts) - 1];
+	$sub_dir = str_replace(array($doc_root, $this_script), "", $php_self);
+	$sub_dir_parts = explode('/', $sub_dir);
+	$connect_path = $doc_root . '/' . $sub_dir_parts[0] . "/connect/";
+}
+include($connect_path . "config.php");
+include($connect_path . "db_connect.php");
 include("clean_var.php");
 
 // If alternate go back specified, then use that if any errors.  This is usefull if sending page session expires when back button is used.
