@@ -12,8 +12,5 @@
 	$special = $_POST['special'];
 	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "head WHERE head_name='$head_name'";
 	$result = $bwb_dbh->query($query);
-	if ($row = $result->fetch(PDO::FETCH_ASSOC))
-		print "1";
-	else
-		print "0";
+	echo $result->rowCount();
 ?>
\ No newline at end of file
