@@ -4,6 +4,8 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 7/7/2012	ELL
+// Revised: 5/2/2017	ELL
+// Modified to use first and last name instead of user ID is not blank.
 // 
 //
 
@@ -40,7 +42,11 @@ $mode = $_REQUEST['mode'];
 	$blog_time_stamp = date("n-j-Y g:i:s A");
 	
 	$content_html = str_replace("mm/dd/yyyy hh:ii:ss PM", $blog_time_stamp, $content_html);
-	$content_html = str_replace("Username", $userid, $content_html);
+	if ((isset($first_name) && ($first_name != "")) || (isset($last_name) && ($last_name != "")))
+		$name = $first_name . " " . $last_name;
+	else
+		$name = $userid;
+	$content_html = str_replace("Username", $name, $content_html);
 	
 	//Add blog to database.
 	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "blogs` SET `page_name`='$page_name', `post`='$content_html', `owner`='$userid', `revised`='$today'";
