@@ -6,6 +6,8 @@
 // Completely revised: 12/17/2010	ELL
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
 // 
 
 	include ("check_session.php");
@@ -13,12 +15,8 @@
 	$ID = $_POST['IDRemove'];
 	$menu = $_POST['menu'];
 	
-	$suffix = substr($menu, 4);
-	$menu_items_table = "menu"  . $suffix . "_items";
-		
-	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . $menu_items_table . "` WHERE `ID` = '$ID'";
+	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "menu_items` WHERE `menu`='$menu' AND `ID` = '$ID'";
 	$cnt = $bwb_dbh->exec($query);
 	
-	header("Location: populate_menu_items.php?menu=$menu");
-	
+	header("Location: populate_menu_items.php?menu=$menu");	
 ?>
