@@ -12,19 +12,21 @@
 
 	$user_name = $_REQUEST['user_name'];
 	$table = $_REQUEST['table'];
+	$no_prefix = $_REQUEST['no_prefix'];
 	
-	if ($table == "-not selected-")
+	if (!isset($table) || ($table == "-not selected-") || ($table == ""))
 	{
-		echo "You must select a table first to delete a user from.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to select a table and try again.";
+		echo MANAGE_USERS_NO_TABLE_TO_DELETE_USER_FROM_ERR . " " . CLICK_WORD . " <a href=\"manage_page_access.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR;
 		exit;
 	}
-
+	
+	if (isset($no_prefix) && ($no_prefix == 1))
+		$prefix = "";
+	else
+		$prefix = BWB_TABLE_PREFIX;
 	
 	// Go ahead and delete page record from table.
-	if ((!$table) || ($table == ""))
-		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "users WHERE UserID = '$user_name'";
-	else
-		$query = "DELETE FROM " . $table . " WHERE UserID = '$user_name'";
+	$query = "DELETE FROM " . $prefix . $table . " WHERE UserID = '$user_name'";
 		
 	$cnt = $bwb_dbh->exec($query);
 	
