@@ -97,7 +97,7 @@
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 <?php	if ($favicon_uploaded == 1)	{	?>
 	popup_msg.top_offset = 100;
 	popup_msg.left_offset = 320;
