@@ -20,14 +20,22 @@
 <title>Edit Head Select | Breeze Website Builder</title>
 <link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
 
-<script language="javascript" type="text/javascript" src="js/edit_head_select.js"></script>
+<style>
+#btn_manage_head_code	{
+	background-attachment:scroll;
+	background-repeat:no-repeat;
+	background-position: 5px -1px;
+}
+</style>
+
+<script src="js/edit_head_select.js"></script>
 
 </head>
 
 <body>
 <div id="sub_level_1_buttons">
 
-          <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo EDIT_HEAD_SELECT_HEADING; ?></div><div class="button_heading_help" onclick="OpenHelpWindow();">&nbsp;</div></div>
+          <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo EDIT_HEAD_SELECT_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow('edit_head');">&nbsp;</div></div>
 		    <?php
 			$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head ORDER BY head_name";
 			$result = $bwb_dbh->query($query);
@@ -44,6 +52,10 @@
 			}
 		?>
       
+      <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_HEAD_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow('manage_head');">&nbsp;</div></div>
+        
+        <div class='button_sub_level_1' onClick="window.location='manage_head.php';" id="btn_manage_head_code"><span class='button_text_sub_level_1' style="left:35px;"><?php echo MANAGE_HEAD_MANAGE_BTN; ?></span></div>
+
 </div>
 </body>
 </html>
\ No newline at end of file
