@@ -19,6 +19,10 @@
 // Removed obsolete "saved" var.
 // Revised: 7/19/2015	ELL
 // Fixed bug with getting mobile menu items.
+// Revised: 10/22/2016	ELL
+// Added population of mega menu array.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
 // 
 //
 
@@ -54,6 +58,12 @@
 	padding-left:5px;
 	padding-right:5px;
 }
+
+#manage_mega_menu_btn	{
+	width:210px;
+	position:absolute;
+	right:100px;
+}
 </style>
 
 <script type="text/javascript" src="js/json2.js"></script>
@@ -68,6 +78,8 @@
 <script language="javascript" type="text/javascript" >
 
 var update_all = false;
+var unsaved_new_item = false;
+var curr_item_under_edit = "";
 var pages = new Array();
 var pages_full = new Array();
 var bgclr = "#eeeeee";
@@ -75,10 +87,11 @@ var bgclr = "#eeeeee";
 <?php
 	echo "	var theme = '$theme';\n\n";
 	
+	echo "pages = new Array();\n";
+	echo "pages_full = new Array();\n";
 	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
 	$result = $bwb_dbh->query($query);
 	$num_results = $result->rowCount();
-	$page_name_tmp = "";
 	for ($j = 0; $j < $num_results; $j++)
 	{
 		$row = $result->fetch(PDO::FETCH_ASSOC);
@@ -89,6 +102,18 @@ var bgclr = "#eeeeee";
 	}
 	echo "	var page_cnt = $j;\n\n";
 	
+	echo "mega_menus = new Array();\n";
+	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name LIKE 'mm_%' ORDER BY page_name";
+	$result = $bwb_dbh->query($query);
+	$num_results = $result->rowCount();
+	for ($j = 0; $j < $num_results; $j++)
+	{
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$mega_menu = $row["page_name"];
+		echo "mega_menus[$j] = '$mega_menu';\n";
+	}
+	echo "	var mega_menu_cnt = $j;\n\n";
+	
 	echo "	var EDIT_MENU_ITEMS_ITEM_TEXT = \"" . EDIT_MENU_ITEMS_ITEM_TEXT . "\";\n";
 	echo "	var EDIT_MENU_ITEMS_NESTING_LEVEL = \"" . EDIT_MENU_ITEMS_NESTING_LEVEL . "\";\n";
 	echo "	var EDIT_MENU_ITEMS_URL = \"" . EDIT_MENU_ITEMS_URL . "\";\n";
@@ -126,6 +151,8 @@ var bgclr = "#eeeeee";
 	echo "	var ENTER_FRAME_NAME = \"" . ENTER_FRAME_NAME . "\";\n";
 	echo "	var EDITOR_STARTING_UPDATE_MSG = \"" . EDITOR_STARTING_UPDATE_MSG . "\";\n";
 	echo "	var _NOT_SELECTED_ = \"" . _NOT_SELECTED_ . "\";\n";
+	echo "	var EDIT_MENU_ITEMS_MEGA_MENU = \"" . EDIT_MENU_ITEMS_MEGA_MENU . "\";\n";
+	echo "	var EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG = \"" . EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG . "\";\n";
 ?>
 </script>
 
@@ -144,7 +171,7 @@ var bgclr = "#eeeeee";
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
 <?php
 	$use_default_menu = 0;
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus`";
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus ORDER BY description, menu_name";
 	$result = $bwb_dbh->query($query);
 	$use_default_menu = $result->rowCount();
 	while($row = $result->fetch(PDO::FETCH_ASSOC))
@@ -161,16 +188,8 @@ var bgclr = "#eeeeee";
 	
     <div id='select_menu_msg_div'>
 <?php
-	if (($use_default_menu == 2) && ($menu == ""))
-		$menu_source = "menu1_items";
-	elseif (($menu == "-not selected-") || ($menu == ""))
+	if (($use_default_menu != 2) && (($menu == "-not selected-") || ($menu == "")))
 		echo "<br /><br />" . EDIT_MENU_ITEMS_SELECT_MENU_MSG;
-	else
-	{
-		$suffix = substr($menu, 4);
-		$suffix = str_replace("_mobile", "", $suffix);
-		$menu_source  = "menu" . $suffix . "_items";
-	}
 ?>
 	</div>
     
@@ -188,10 +207,12 @@ var bgclr = "#eeeeee";
 
 </div>
 
+<div class='button_console_manage_menu' onClick="window.location='manage_mega_menu.php';" id="manage_mega_menu_btn"><span class='button_console_text_w_icon'><?php echo MEGA_MENU_MANAGE_BTN; ?></span></div>
+
 <?php include("lib/popup_msg.html"); ?>
 
 <script language='javascript' type='text/javascript'>
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 <?php
 	if (isset($menu))
 		echo "      RetrieveMenuItems();\n";
