@@ -1,5 +1,5 @@
 <?php
-// FormMailer, copyright 2007-2011, EB Dynamics, Inc., Ed Lemmers
+// FormMailer, copyright 2007-2018, Silver Dolphin Solutions, LLC, Ed Lemmers
 // For licensing, see license.txt.
 //
 // This module may be customized to your needs, however, the design is intended to cover all
@@ -25,8 +25,21 @@ $referers = array($server_name_www, $server_name);
 // Module for performaing actual email operation.
 include("mime_mail.inc");
 // DB connection for retrieving HTML message format for message back to inquirer, etc.
-include("../connect/db_connect.php");
-include("../connect/config.php");
+$doc_root = $_SERVER['DOCUMENT_ROOT'];
+if (file_exists("../connect/config.php"))	// Default installation
+	$connect_path = "../connect/";
+elseif (file_exists($doc_root . "/connect/config.php"))	// Custom userfile folders
+	$connect_path = $doc_root . "/connect/";
+else	{	// Must be installeed in sub domain or sub folder with non-standard userfile folders.
+	$php_self = $_SERVER["PHP_SELF"];
+	$self_parts = explode('/', $php_self);
+	$this_script = $self_parts[count($self_parts) - 1];
+	$sub_dir = str_replace(array($doc_root, $this_script), "", $php_self);
+	$sub_dir_parts = explode('/', $sub_dir);
+	$connect_path = $doc_root . '/' . $sub_dir_parts[0] . "/connect/";
+}
+include($connect_path . "config.php");
+include($connect_path . "db_connect.php");
 include("clean_var.php");
 // List of key fields to ignore (not customer data, but rather configuration hidden fields).
 include("ignore_fields.php");
@@ -238,7 +251,7 @@ if ($_POST['use_captcha'])
 	
 	if (!isset($_POST['captcha_type']) || ($_POST['captcha_type'] == "recaptcha"))
 	{
-	  include("../connect/captchakeys.php");
+	  include($connect_path . "captchakeys.php");
 	  require_once('recaptchalib.php');
 	  $resp = recaptcha_check_answer (RECAPTCHA_PRIVATE_KEY,
 									$_SERVER["REMOTE_ADDR"],
@@ -250,7 +263,7 @@ if ($_POST['use_captcha'])
 	}
 	elseif ($_POST['captcha_type'] == "recaptcha2")
 	{
-		include("../connect/captchakeys.php");
+		include($connect_path . "captchakeys.php");
 		require_once('recaptchalib2.php');
 		// The response from reCAPTCHA
 		$resp = null;
@@ -273,7 +286,7 @@ if ($_POST['use_captcha'])
 	elseif ($_POST['captcha_type'] == "mollom")	// Requires acquisition of public and private keys from http://mollom.com
 	{
 		require_once("mollom.php");
-		include("../connect/captchakeys.php");
+		include($connect_path . "captchakeys.php");
 		
 		$captcha_response_field = $_POST['captcha_response_field'];
 		$mollom_session = $_POST['mollom_session'];
