@@ -14,6 +14,8 @@
 // Added SEF URL switching.
 // Added checking of existing entries from other menus to avoid duplicate entries.
 // Added checking of all pages to include pages not found in menues.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
 //
 
 	// for testing //
@@ -39,9 +41,8 @@
 	while ($row_menus = $result_menus->fetch(PDO::FETCH_ASSOC))
 	{
 		$menu_name = $row_menus['menu_name'];
-		$suffix = substr($menu_name, 4);
 		
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu" . $suffix . "_items ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu_items WHERE menu='" . $menu_name . "' ORDER BY sort_order";
 //		echo "$query<br>";
 		$result = $bwb_dbh->query($query);
 		if ($result->rowCount() > 0)
@@ -84,7 +85,13 @@
 						{
 							if (SEF_URL == 1)
 							{
-								if (strpos($URL, $special_chars) === false)
+								$found_special_char = false;
+								foreach ($special_chars as $char)
+								{
+									if (strpos($URL, $chars) !== false)
+										$found_special_char = true;
+								}
+								if ($found_special_char === false)
 									$URL = $page_name;
 							}
 							
@@ -235,14 +242,14 @@
 			echo GENERATE_SITE_MAP_COULD_NOT_RENAME_1_ERR . " $file_name " . GENERATE_SITE_MAP_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
 		else
 			$msg = GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE;
-		@chmod($bkup_file_name, 0755);
+		@chmod($bkup_file_name, 0644);
 	}
 	
 	// Create sitemap.xml file.
 	$fh = fopen($file_name, 'x') or die(GENERATE_SITE_MAP_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 	$result = (fputs($fh, $site_map_string));
 	fclose($fh) or die($php_errormsg);
-	@chmod($file_name, 0755);
+	@chmod($file_name, 0644);
 	if ($msg != GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE)
 		$msg = GENERATE_SITE_MAP_SITEMAP_CREATION_COMPLETE;
 	
@@ -255,9 +262,11 @@
 	$robots_string .= "Disallow: /ckeditor/\n";
 	$robots_string .= "Disallow: /kfm/\n";
 	$robots_string .= "Disallow: /php/\n";
-	$robots_string .= "Disallow: /scripts/\n";
-	$robots_string .= "Disallow: /css/\n";
-	$robots_string .= "Disallow: /wizard/\n";
+	// Google needs to see JavaScirpt and images, so the next 2 lines have been commented out.
+//	$robots_string .= "Disallow: /scripts/\n";
+//	$robots_string .= "Disallow: /css/\n";
+	if (file_exists($document_root . "/wizard"))
+		$robots_string .= "Disallow: /wizard/\n";
 	$robots_string .= "Sitemap: http://" . $website . $website_file_path . "/sitemap.xml";
 	$file_name = $document_root . $website_file_path . "/robots.txt";
 	if (!file_exists($file_name))
@@ -265,12 +274,13 @@
 		$fh = fopen($file_name, 'x') or die(GENERATE_SITE_MAP_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 		$result = (fputs($fh, $robots_string));
 		fclose($fh) or die($php_errormsg);
-		@chmod($file_name, 0755);
+		@chmod($file_name, 0644);
 	}
 	$file_name2 = $document_root . "/robots.txt";
 	// Copy robots.txt to site root.
-	if (!file_exists($file_name2))	{
+	if (file_exists($file_name2) && (trim($file_name) != trim($file_name2)))	{
+		unlink($file_name2);
 		copy($file_name, $file_name2);
-		$msg .= "<br /><br />" . GENERATE_SITE_MAP_ROBOT_FILE_CREATED;
 	}
+	$msg .= "<br /><br />" . GENERATE_SITE_MAP_ROBOT_FILE_CREATED;
 ?>
