@@ -103,7 +103,10 @@ $kfm->defaultSetting('allow_directory_move',1);
 $kfm->defaultSetting('folder_drag_action',3);
 $kfm->defaultSetting('default_directories',array());
 $kfm->defaultSetting('default_directory_permission',755);
-$kfm->defaultSetting('banned_folders',array('/^\./'));
+//////////////////// Breeze Website Builder upload modification ///////////////////////////
+//$kfm->defaultSetting('banned_folders',array('/^\./'));
+$kfm->defaultSetting('banned_folders',array('/^\./', "kfm", "manage", "ckeditor", "connect", "wizard", "cgi-bin"));
+//////////////////// Breeze Website Builder upload modification ///////////////////////////
 $kfm->defaultSetting('allowed_folders',array());
 //files
 $kfm->defaultSetting('allow_file_create',1);
