@@ -6,6 +6,10 @@
 // Created: 4/9/2013
 // Revised: 12/13/2013	ELL
 // Added refresh of main menu to update buttons and set to last selections.
+// Revised: 9/28/2016	ELL
+// Modified file copying to accomodate possibility that zip archive extracts to non-Breeze staging folder.
+// Revised: 6/20/2017	ELL
+// Added ability to deploy 'Console Only' plugins upon install.
 //
 	
 	include ("check_session.php");
@@ -104,6 +108,26 @@
 		// Copy files to correct folders.
 		echo INSTALL_PLUGIN_COPYING_FILES . "<br><br>\n";
 		$extracted_source = $document_root . "/tmp";
+		// Examine to see if files zipped to archive including some staging directory.  If so, then need to include that folder in the source path to get correct paths.
+		$breeze_dirs = array("manage", "ckeditor", "kfm", "connect", "scripts", "php");
+		$dir_arr = array();
+		$got_breeze_dir = 0;
+		if ($handle = opendir($extracted_source)) 
+		{
+			while (false !== ($file = readdir($handle)))
+			{
+				if (is_dir($extracted_source . "/" . $file) && ($file != ".") && ($file != ".."))
+				{
+					if (in_array($file, $breeze_dirs))
+						$got_breeze_dir++;
+					$dir_arr[] = $file;
+				}
+			}
+			closedir($handle);
+		}
+		if (($got_breeze_dir < 1) && (count($dir_arr) == 1))	// Zip file must be extracting to some containing folder that has nothing to do with Breeze file tree.  Include in path.
+			$extracted_source .= "/" . $dir_arr[0];
+		
 		$destination = $document_root;
 		copydir($extracted_source, $destination, 0755, true);
 		unlink($document_root . "/plugin.sql");
@@ -113,8 +137,24 @@
 		
 		// Run template SQL
 		$sql_file = "plugin.sql";
+		if (($got_breeze_dir < 1) && (count($dir_arr) == 1))	// If extracted to additional containing folder, include that foler in path to SQL file.
+			$sql_file = $dir_arr[0] . "/" . $sql_file;
 		include ("run_sql_file.php");
 		
+		// Check for "Console Only" plugin and deploy now if so.
+		$id = $bwb_dbh->lastInsertId();
+		$query = "SELECT name, category, plugin_sql FROM " . BWB_TABLE_PREFIX . "plugins WHERE id = " . $id;
+		$result = $bwb_dbh->query($query);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		if ($row['category'] == "Console Only")	{
+			$plugin_sql = $row['plugin_sql'];
+			if (isset($plugin_sql) && ($plugin_sql != ""))
+				$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+		
+			$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$id, `deployed`=1";
+			$cnt = $bwb_dbh->exec($query);
+		}
+		
 		$_SESSION['button_group'] = "other_functions";
 		$_SESSION['button'] = "btn_users_site_options";
 		$_SESSION['sub_button'] = "btn_upload_plugin";
@@ -122,7 +162,25 @@
 ?>
 		<h2><?php echo INSTALL_PLUGIN_PLUGIN_INSTALLATION_COMPLETE; ?></h2>
         <p><?php echo CLICK_WORD; ?> <a href="main.php" target="_top"><?php echo HERE_WORD; ?></a> <?php echo INSTALL_PLUGIN_ADD_NEW_BUTTON_TO_MENU_MSG; ?></p>
-
+<script>
+	var bottom = document.body.scrollHeight;
+	var from_height = 0;
+	var step = parseInt(bottom/100);
+	var to_height = 0;
+	var code = "AnimateScroll();";
+	
+	function AnimateScroll()
+	{
+		if (to_height < bottom)
+		{
+			to_height = to_height + step;
+			window.scrollTo(from_height, to_height);
+			setTimeout(code, 10);
+			from_height = to_height;
+		}
+	}
+	AnimateScroll();
+</script>
 <?php
 	}
 	else
