@@ -150,6 +150,26 @@
 		$extracted_source = $document_root . "/tmp";
 		$destination = $document_root;
 		copydir($extracted_source, $destination, 0755, true);
+		$scripts_source = $extracted_source . "/scripts";
+		$lib_source = $extracted_source . "/php";
+		if (BWB_BASE_DIR == '')
+		{
+			if (BWB_LIB_DIR != "php")	{
+				$lib_dir = $document_root . "/" . BWB_LIB_DIR;
+				copydir($lib_source, $lib_dir, 0755, true);
+			}
+			if (BWB_SCRIPTS_DIR != "scripts")	{
+				$scripts_dir = $document_root . "/" . BWB_SCRIPTS_DIR;
+				copydir($scripts_source, $scripts_dir, 0755, true);
+			}
+		}
+		else
+		{
+			$lib_dir = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_LIB_DIR;
+			$scripts_dir = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR;
+			copydir($lib_source, $lib_dir, 0755, true);
+			copydir($scripts_source, $scripts_dir, 0755, true);
+		}
 		unlink($source);
 		unlink($tar_source);
 		
