@@ -6,7 +6,6 @@
 // Created: 2/27/2018	ELL
 
 echo "<script src='" . $scripts_dir_rel . "jquery.min.js'> </script>\n\n";
-
 ?>
 <script>
 	function is_touch_device() {
@@ -18,4 +17,8 @@ echo "<script src='" . $scripts_dir_rel . "jquery.min.js'> </script>\n\n";
 	if (is_touchscreen)
 		touchscreen = 1;
 	$.post( "<?php echo $php_dir_rel; ?>set_is_touchscreen.php", { is_touchscreen: touchscreen } ) ;
+	
+	var got_mobile = <?php if ($is_mobile === true) echo "true"; else echo "false"; ?>;
+	if (is_touchscreen && !got_mobile)
+		location.reload();
 </script>
