@@ -47,14 +47,14 @@ function DeleteConfirm(delete_mode)
 		popup_msg.popup_msg_cell = "Are your sure you want to delete the <b>" + document.getElementById("selectPageToDelete").value + "</b> page?";
 		document.getElementById("popup_button_2_span").onclick = function() { DeletePage(); };
 	}
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	popup_msg.ShowPopupMsg();
 }
 
 function RecallPlugin()
 {
 	var plugin_id = document.getElementById("recall_plugin").value;
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	var url = "recall_plugin.php?plugin_id=" + plugin_id;
 	window.location = url;
 }
