@@ -21,6 +21,8 @@
 // Added ability to copy from all classes by checking checkbox.
 // Modified: 11/14/2017	ELL
 // Added checking between class prefix and class to avoid redundancy and inconsistency.
+// Modified: 3/15/2018	ELL
+// Added standard HTML elements to subclass adder list if not editing site, site_mobile, browser_reset or browser_reset_mobile styles.
 
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
@@ -44,9 +46,9 @@ function InitializeConsole()
 //////////////////////////////////////////////////////////////////////////////////////
 function GetClassLists()
 {
-	$.post( "get_classes.php", { style_sheet: style_sheet } ).done(PopulateClassLists) ;
+	$.post( "get_classes.php", { style_sheet: style_sheet }, function( data ) {PopulateClassLists(data, style_sheet) } ) ;
 }
-function PopulateClassLists(data)
+function PopulateClassLists(data, style_sheet)
 {
 	var list_delim = ":::::";
 	var row_delim = "@@@@@";
@@ -115,6 +117,63 @@ function PopulateClassLists(data)
 	html_subclass = html_subclass + "<option value=':required'>:required</option>\n";
 	html_subclass = html_subclass + "<option value=':optional'>:optional</option>\n";
 	html_subclass = html_subclass + "<option value=':root'>:root</option>\n";
+	
+	if ((style_sheet.indexOf("site", 0) < 0) && (style_sheet.indexOf("browser_reset", 0) < 0))
+	{
+		html_subclass = html_subclass + "<option value='body'>body</option>\n";
+		html_subclass = html_subclass + "<option value='table'>table</option>\n";
+		html_subclass = html_subclass + "<option value='thead'>thead</option>\n";
+		html_subclass = html_subclass + "<option value='tbody'>tbody</option>\n";
+		html_subclass = html_subclass + "<option value='tfoot'>tfoot</option>\n";
+		html_subclass = html_subclass + "<option value='caption'>caption</option>\n";
+		html_subclass = html_subclass + "<option value='tr'>tr</option>\n";
+		html_subclass = html_subclass + "<option value='th'>th</option>\n";
+		html_subclass = html_subclass + "<option value='td'>td</option>\n";
+		html_subclass = html_subclass + "<option value='colgroup'>colgroup</option>\n";
+		html_subclass = html_subclass + "<option value='col'>col</option>\n";
+		html_subclass = html_subclass + "<option value='p'>p</option>\n";
+		html_subclass = html_subclass + "<option value='h1'>h1</option>\n";
+		html_subclass = html_subclass + "<option value='h2'>h2</option>\n";
+		html_subclass = html_subclass + "<option value='h3'>h3</option>\n";
+		html_subclass = html_subclass + "<option value='h4'>h4</option>\n";
+		html_subclass = html_subclass + "<option value='a:link'>a:link</option>\n";
+		html_subclass = html_subclass + "<option value='a:visited'>a:visited</option>\n";
+		html_subclass = html_subclass + "<option value='a:hover'>a:hover</option>\n";
+		html_subclass = html_subclass + "<option value='a:active'>a:active</option>\n";
+		html_subclass = html_subclass + "<option value='ul'>ul</option>\n";
+		html_subclass = html_subclass + "<option value='ol'>ol</option>\n";
+		html_subclass = html_subclass + "<option value='li'>li</option>\n";
+		html_subclass = html_subclass + "<option value='hr'>hr</option>\n";
+		html_subclass = html_subclass + "<option value='blockquote'>blockquote</option>\n";
+		html_subclass = html_subclass + "<option value='div'>div</option>\n";
+		html_subclass = html_subclass + "<option value='span'>span</option>\n";
+		html_subclass = html_subclass + "<option value='header'>header</option>\n";
+		html_subclass = html_subclass + "<option value='footer'>footer</option>\n";
+		html_subclass = html_subclass + "<option value='address'>address</option>\n";
+		html_subclass = html_subclass + "<option value='form'>form</option>\n";
+		html_subclass = html_subclass + "<option value='fieldset'>fieldset</option>\n";
+		html_subclass = html_subclass + "<option value='legend'>legend</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='text']\">input[type='text']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='checkbox']\">input[type='checkbox']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='radio']\">input[type='radio']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='button']\">input[type='button']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='submit']\">input[type='submit']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='reset']\">input[type='reset']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='password']\">input[type='password']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='image']\">input[type='image']</option>\n";
+		html_subclass = html_subclass + "<option value=\"input[type='file']\">input[type='file']</option>\n";
+		html_subclass = html_subclass + "<option value='textarea'>textarea</option>\n";
+		html_subclass = html_subclass + "<option value='select'>select</option>\n";
+		html_subclass = html_subclass + "<option value='option'>option</option>\n";
+		html_subclass = html_subclass + "<option value='label'>label</option>\n";
+		html_subclass = html_subclass + "<option value='dl'>dl</option>\n";
+		html_subclass = html_subclass + "<option value='dt'>dt</option>\n";
+		html_subclass = html_subclass + "<option value='dd'>dd</option>\n";
+		html_subclass = html_subclass + "<option value='iframe'>iframe</option>\n";
+		html_subclass = html_subclass + "<option value='img'>img</option>\n";
+		html_subclass = html_subclass + "<option value='html'>html</option>\n";
+	}
+
 	html_subclass = html_subclass + "</select>\n";
 	document.getElementById("subclass_div").innerHTML = html_subclass;
 	
