@@ -5,6 +5,11 @@
 // Created: 1/13/2015	ELL
 // Revised:	2/2/2012	ELL
 // Fixed bug of "Save As" not creating new file.
+// Revised: 1/12/2016	ELL
+// Modified error handling for attempting to rename page to existing page to have nice AJAX-like experience.
+
+var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
+var popup_msg = new PopupMsg(param_array);
 
 window.parent.document.title = document.title;
 
@@ -15,8 +20,10 @@ function OpenHelpWindow()
 
 function CheckPageName(page_name)
 {
-	if ((page_name.length > 0) && (page_name != " "))
+	if ((page_name.length > 0) && (page_name != " "))	{
 		document.getElementById("copy_rename_btn").className = "button_console_edit";
+		document.getElementById("new_name").className = "";
+	}
 	else
 		document.getElementById("copy_rename_btn").className = "button_console_edit_disabled";
 }
@@ -51,6 +58,12 @@ function TransferPageNameOnCheck(checkbox_el)
 		document.getElementById("create_new_template").value = 0;
 }
 
+function CopyRenamePage()
+{
+	if (document.getElementById("copy_rename_btn").className != "button_console_edit_disabled")
+		document.getElementById('frmRenamePage').submit();
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
