@@ -3,6 +3,8 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 3/1/2015	ELL
+// Revised: 3/30/2017	ELL
+// Added ability to sort style sheets alphabetically.
 
 window.parent.document.title = document.title;
 
@@ -11,6 +13,15 @@ function OpenHelpWindow(topic)
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
+function ChangeStyleSheetSort(bAlpha)
+{
+	sort_alpha = 0;
+	if (bAlpha === true)
+		sort_alpha = 1;
+
+	window.location = "edit_css_select.php?sort_alpha=" + sort_alpha;
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
