@@ -11,8 +11,11 @@
 // Converted editor for simple text area to CKEditor is source view.
 // Revised: 12/1/2014	ELL
 // Added revert confirmation message.
+// Revised: 11/10/2016	ELL
+// Modified custom CSS editing to allow for any number of custom CSS records associated with custom style sheets.
 
 var mTimer;
+var lockoutChangeCheck = true;
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -27,12 +30,25 @@ function OpenHelpWindow()
 ////////////////////////////////////////////////////////////////////////////////////
 function LoadCSS()
 {
-	$.post( "get_custom_css.php", { custom_site_css_table: custom_site_css_table } ).done(CompleteLoadCSS) ;
+	$.post( "get_custom_css.php", { style_sheet: style_sheet } ).done(CompleteLoadCSS) ;
 }
 function CompleteLoadCSS(data)
 {
 //	alert(data);
 	CKEDITOR.instances['editorContainer'].setData(data);
+	
+	mTimer = setTimeout("StartChangeCheckTimer();", 4000);
+	bwb_ckeditor.commands.save.disable();
+}
+
+function StartChangeCheckTimer()
+{
+	bwb_ckeditor.commands.save.disable();
+	saved = true;
+	window.parent.SetWorkSavedNotSaved(true);
+	bwb_ckeditor.resetDirty();
+	mTimerCheckDirty = setInterval("somethingChanged();", 8000);
+	lockoutChangeCheck = false;
 }
 
 function Save(action)
@@ -46,7 +62,7 @@ function Save(action)
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
 	
-	$.post( "save_custom_css.php", { custom_css: custom_css, action: action, custom_site_css_table: custom_site_css_table, style_sheet: style_sheet } ).done(CompleteSave) ;
+	$.post( "save_custom_css.php", { custom_css: custom_css, action: action, style_sheet: style_sheet } ).done(CompleteSave) ;
 }
 function CompleteSave(data)	{
 	popup_msg.status_msg = data;
@@ -69,7 +85,7 @@ function RevertConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { Revert(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 function Revert()
 {	
@@ -78,7 +94,7 @@ function Revert()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	
-	$.post( "revert_custom_css.php", { custom_site_css_table: custom_site_css_table } ).done(CompleteRevert) ;
+	$.post( "revert_custom_css.php", { style_sheet: style_sheet } ).done(CompleteRevert) ;
 }
 function CompleteRevert(data)	{
 	if (data == "No draft found")
@@ -96,14 +112,16 @@ function DisplayNotSavedMessage(btn)
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
-	popup_msg.popup_btn_cnt = 2;
+	popup_msg.popup_btn_cnt = 3;
 	popup_msg.popup_msg_cell = EDITOR_CSS_NOT_SAVED_MSG;
 	popup_msg.popup_button_2_span = YES_WORD;
 	popup_msg.popup_button_1_span = NO_WORD;
+	popup_msg.popup_button_3_span = CANCEL_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { SaveBeforeMain(); };
 	document.getElementById("popup_button_1_span").onclick = function () { DoMainMenuAction(); };
+	document.getElementById("popup_button_3_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function PreviewPageSelect()
@@ -119,7 +137,7 @@ function Preview(page_name, do_refresh)
 	document.getElementById("page_select_div").style.display = "none";
 	var custom_css = CKEDITOR.instances['editorContainer'].getData();
 	
-	$.post( "save_custom_css.php", { custom_css: custom_css, action: "Preview", custom_site_css_table: custom_site_css_table, style_sheet: style_sheet }, function(data){ ShowPreview(data, do_refresh, page_name); }, "text" ) ;
+	$.post( "save_custom_css.php", { custom_css: custom_css, action: "Preview", style_sheet: style_sheet }, function(data){ ShowPreview(data, do_refresh, page_name); }, "text" ) ;
 }
 function ShowPreview(data, do_refresh, page_name)
 {
