@@ -28,12 +28,12 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteFavicon(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteFavicon()
 {
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	var url = "delete_favicon.php";
 	window.location = url;
 }
\ No newline at end of file
