@@ -14,6 +14,7 @@
 // Added "Save As"
 
 var mTimer;
+var lockoutChangeCheck = true;
 
 var browser = BrowserDetect.browser;
 var browser_version = BrowserDetect.version;
@@ -37,6 +38,19 @@ function CompleteLoadHead(data)
 {
 //	alert(data);
 	CKEDITOR.instances['editorContainer'].setData(data);
+	
+	mTimer = setTimeout("StartChangeCheckTimer();", 4000);
+	bwb_ckeditor.commands.save.disable();
+}
+
+function StartChangeCheckTimer()
+{
+	bwb_ckeditor.commands.save.disable();
+	saved = true;
+	window.parent.SetWorkSavedNotSaved(true);
+	bwb_ckeditor.resetDirty();
+	mTimerCheckDirty = setInterval("somethingChanged();", 8000);
+	lockoutChangeCheck = false;
 }
 
 function Save(action)
@@ -74,7 +88,7 @@ function RevertConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { Revert(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 function Revert()
 {	
@@ -130,14 +144,16 @@ function DisplayNotSavedMessage(btn)
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
-	popup_msg.popup_btn_cnt = 2;
+	popup_msg.popup_btn_cnt = 3;
 	popup_msg.popup_msg_cell = EDITOR_HEAD_NOT_SAVED_MSG;
 	popup_msg.popup_button_2_span = YES_WORD;
 	popup_msg.popup_button_1_span = NO_WORD;
+	popup_msg.popup_button_3_span = CANCEL_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { SaveBeforeMain(); };
 	document.getElementById("popup_button_1_span").onclick = function () { DoMainMenuAction(); };
+	document.getElementById("popup_button_3_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function SaveBeforeMain()
@@ -165,12 +181,12 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteHead(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteHead()
 {
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	var url = "delete_head.php?head_name=" + head_name + "&redirect=edit_head_select.php";
 	window.location = url;
 }
@@ -187,7 +203,7 @@ function ShowSaveAsMsg()
 	popup_msg.popup_button_1_span = OK_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
-	document.getElementById("popup_button_2_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_2_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	document.getElementById("popup_button_1_span").onclick = function () { SaveAs(); };
 }
 
@@ -202,10 +218,11 @@ function SaveAs()
 	}
 	new_head_name = "head_" + new_head_name;
 	
-	var head_exists;
-	$.post( "check_head_exists.php", { head_name: new_head_name }, function(data){ head_exists = data; }, "text" ) ;
-		
-	if (head_exists == "1")
+	$.post( "check_head_exists.php", { head_name: new_head_name }, function(data){ CompleteSaveAs(data, old_head_name, new_head_name); } ) ;
+}
+function CompleteSaveAs(data, old_head_name, new_head_name)
+{
+	if (data > 0)
 		alert(EDITOR_HEAD_ALREADY_EXISTS_1_ERR + " " + new_head_name + " " + EDITOR_HEAD_ALREADY_EXISTS_2_ERR);
 	else
 	{
@@ -219,9 +236,8 @@ function SaveAs()
 		var new_title = new_head_name + " - Editing | Breeze Website Builder";
 		document.title = new_title;
 		window.parent.document.title = document.title;
+		popup_msg.HidePopupMsg();
 	}
-	
-	HidePopupMsg();
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
