@@ -9,6 +9,10 @@
 // Implemented popup message class.
 // Revised: 12/22/2013	ELL
 // Restored ability to check for saved and prompt user for action.
+// Revised: 10/22/2016	ELL
+// Added handling of mega menus.
+// Revised: 4/13/2017	ELL
+// Added code to update HTML on every change because JavaScript ignores form entry.
 //
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
@@ -48,14 +52,14 @@ function DeleteConfirm(item_text, ID, i)
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteMenuItem(ID); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteMenuItem(IDRemove)
 {
 	var params = "";
 
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	menu = document.getElementById("selectMenu").value;
 	
 	popup_msg.popup_msg_type = 1;
@@ -89,19 +93,22 @@ function UpdateMenuItem(ID, i)
 		UpdateAll();
 		return;
 	}
-		
 	var params = "";
 	var ID_ctl = "ID" + i;
 	var item_text_ctl = "item_text" + i;
 	var level_ctl = "level" + i;
 	var URL_ctl = "URL" + i;
 	var target_ctl = "target" + i;
+	var mega_menu_ctl = "mega_menu" + i;
 	var sort_order_ctl = "sort_order" + i;
 	var item_text = "";
 	var URL = "";
+	
+	if (ID == -1)
+		unsaved_new_item = false;
 
 	popup_msg.popup_msg_type = 1;
-	popup_msg.status_msg = "Starting update...";
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
 	popup_msg.popup_timeout = -1;
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
@@ -128,6 +135,7 @@ function UpdateMenuItem(ID, i)
 		params = params + "&level=" + document.getElementById(level_ctl).value;
 		params = params + "&URL=" + URL;
 		params = params + "&target=" + document.getElementById(target_ctl).value;
+		params = params + "&mega_menu=" + document.getElementById(mega_menu_ctl).value;
 		params = params + "&sort_order=" + document.getElementById(sort_order_ctl).value;
 		//alert(params);
 		xmlhttp.send(params);
@@ -143,6 +151,7 @@ function UpdateAll()
 	var level_ctl;
 	var URL_ctl;
 	var target_ctl;
+	var mega_menu_ctl;
 	var sort_order_ctl;
 	var item_text;
 	var URL;
@@ -173,6 +182,7 @@ function UpdateAll()
 			level_ctl = "level" + i;
 			URL_ctl = "URL" + i;
 			target_ctl = "target" + i;
+			mega_menu_ctl = "mega_menu" + i;
 			sort_order_ctl = "sort_order" + i;
 			
 			params = params + "&ID" + i + "=" + document.getElementById(ID_ctl).value;
@@ -185,11 +195,13 @@ function UpdateAll()
 			URL = EscapeURL(URL);
 			params = params + "&URL" + i + "=" + URL;
 			params = params + "&target" + i + "=" + document.getElementById(target_ctl).value;
+			params = params + "&mega_menu" + i + "=" + document.getElementById(mega_menu_ctl).value;
 			params = params + "&sort_order" + i + "=" + document.getElementById(sort_order_ctl).value;
 		}
 //		alert(params);
 		xmlhttp.send(params);
 	}
+	unsaved_new_item = false;
 	window.parent.SetWorkSavedNotSaved(true);
 }
 
@@ -255,8 +267,19 @@ function UpdateMessage(xmlhttp, Source)
 ////////////////////////////////////////////////////////////////////////////////////
 function AddMenuItem(i)
 {
+	if (unsaved_new_item === true)	{
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG;
+		popup_msg.popup_timeout = -1;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 500;
+		popup_msg.ShowPopupMsg();
+		return;
+	}
+	
 	update_all = true;
 	window.parent.SetWorkSavedNotSaved(false);
+	unsaved_new_item = true;
 	
 	var html = document.getElementById("MenuItemsTable").innerHTML;
 	var cnt = parseInt(document.getElementById("nCount").value);
@@ -280,7 +303,7 @@ function AddMenuItem(i)
 	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='-1'>\n";
-	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='' onchange=\"SetElementValue('item_text" + i + "');\"><\/td>\n";
+	new_row = new_row + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='' onchange=\"SetElementValue('item_text" + i + "', -1);\" onmouseout=\"SetElementVal('item_text" + i + "');\" onkeypress=\"SetCurrentItem('item_text" + i + "', -1);\"><\/td>\n";
 		
 	new_row = new_row + "<td>\n";
 	new_row = new_row + "<input type='hidden' id='level" + i + "' value='' />\n";
@@ -288,26 +311,33 @@ function AddMenuItem(i)
 	new_row = new_row + "<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
-	new_row = new_row + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange=\"result=PopulatePage(" + i + "); SetElementValue('URL" + i + "');\">\n";
+	new_row = new_row + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange=\"PopulatePage(" + i + ");\">\n";
 	new_row = new_row + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
-	
 	for (var k = 0; k < page_cnt; k++)
 	{
 		new_row = new_row + "<option value='" + pages[k] + "'>" + pages[k] + "<\/option>\n";
 	}
 	new_row = new_row + "<\/select>\n";
-	
-	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='' onchange=\"SetElementValue('URL" + i + "');\"><\/td>\n";
+	new_row = new_row + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='' onchange=\"SetElementValue('URL" + i + "', -1);\"><\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n";
-	new_row = new_row + "<select name='target_select" + i + "' id='target_select" + i + "' onChange='PopulateTarget(" + i + ");'>\n";
+	new_row = new_row + "<select name='target_select" + i + "' id='target_select" + i + "' onChange=\"PopulateTarget(" + i + ");\">\n";
 	new_row = new_row + "<option value='_self'>" + SELF_NORMAL + "<\/option>\n";
 	new_row = new_row + "<option value='_blank'>" + NEW_WINDOW + "<\/option>\n";
 	new_row = new_row + "<option value='" + ENTER_FRAME_NAME + "'>" + NAMED_FRAME + "<\/option>\n";
 	new_row = new_row + "<\/select>\n";
 	new_row = new_row + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
-	new_row = new_row + "<td valign='top'>\n<input type='hidden' id='sort_order" + i + "' name='sort_order" + i + "' value='' />\n";
 	
+	new_row = new_row + "<td valign='top'>\n";
+	new_row = new_row + "<select name='mega_menu" + i + "' id='mega_menu" + i + "' onchange=\"SetElementValue(-1, 'mega_menu" + i + "');\">\n";
+	new_row = new_row + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
+	for (var k = 0; k < mega_menu_cnt; k++)
+	{
+		new_row = new_row + "<option value='" + mega_menus[k] + "'>" + mega_menus[k] + "<\/option>\n";
+	}
+	new_row = new_row + "<\/select>\n</td>\n";
+	
+	new_row = new_row + "<td valign='top'>\n<input type='hidden' id='sort_order" + i + "' name='sort_order" + i + "' value='' />\n";
 	new_row = new_row + "<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateMenuItem(-1, " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/plus.png' border=0 alt='Insert Above' name='Insert' onClick=\"AddMenuItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
@@ -319,6 +349,7 @@ function AddMenuItem(i)
 	new_row = new_row + "<td valign='top'>\n<img src='theme/" + theme + "/images/delete.png' border=0 alt='Delete' name='Delete' onClick=\"DeleteConfirm('', -1, " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 	
 	new_row = new_row + "<\/tr>\n";
+
 	var n = i - 1;
 	var rplc_str;
 	for (var j = cnt; j >= i; j--)
@@ -368,6 +399,10 @@ function AddMenuItem(i)
 		rplc_str = "sort_order" + k;
 		html_bottom = html_bottom.replace(srch_str,rplc_str);
 		html_bottom = html_bottom.replace(srch_str,rplc_str);
+		srch_str = "mega_menu" + j;
+		rplc_str = "mega_menu" + k;
+		html_bottom = html_bottom.replace(srch_str,rplc_str);
+		html_bottom = html_bottom.replace(srch_str,rplc_str);
 		srch_str = "UpdateMenuItem(-1, " + j;
 		rplc_str = "UpdateMenuItem(-1, " + k;
 		html_bottom = html_bottom.replace(srch_str,rplc_str);
@@ -482,6 +517,7 @@ function PopulateTable(rows_str)
 	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_NESTING_LEVEL + "<\/b><\/td>\n";
 	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_URL + "<\/b><\/td>\n";
 	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_TARGET_WINDOW + "<\/b><\/td>\n";
+	output_str = output_str + "<td class='header_row'><b>" + EDIT_MENU_ITEMS_MEGA_MENU + "<\/b><\/td>\n";
 	output_str = output_str + "<td>&nbsp;<\/td>\n";
 	output_str = output_str + "<td>&nbsp;<\/td>\n";
 	output_str = output_str + "<td colspan='2'>&nbsp;<\/td>\n";
@@ -508,7 +544,7 @@ function PopulateTable(rows_str)
 			output_str = output_str + "<td valign='top'>\n<img src='theme/" + theme + "/images/indent.png' border=0 alt='Indent' name='Indent' id='Indent" + i + "' onClick=\"IndentItem(" + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
 				
 			output_str = output_str + "<td valign='top'><input type='hidden' name='ID" + i + "' id='ID" + i + "' value='" + JSON_row.ID + "'>\n";
-			output_str = output_str + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='" + Indent(JSON_row.level) + JSON_row.item_text + "'><\/td>\n";
+			output_str = output_str + "<input type='text' name='item_text" + i + "' id='item_text" + i + "' value='" + Indent(JSON_row.level) + JSON_row.item_text + "' onchange=\"SetElementValue('item_text" + i + "', -1);\" onmouseout=\"SetElementVal('item_text" + i + "');\" onkeypress=\"SetCurrentItem('item_text" + i + "', -1);\"><\/td>\n";
 				
 			output_str = output_str + "<td>\n";
 			output_str = output_str + "<input type='hidden' id='level" + i + "' value='" + JSON_row.level + "' />\n";
@@ -527,7 +563,7 @@ function PopulateTable(rows_str)
 			output_str = output_str + "<\/td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n";
-			output_str = output_str + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange='PopulatePage(" + i + ");'>\n";
+			output_str = output_str + "<select name='selectPage" + i + "' id='selectPage" + i + "' onChange=\"PopulatePage(" + i + ");\">\n";
 			output_str = output_str + "<option value=''>-not selected-<\/option>\n";
 			
 			for (var j = 0; j < page_cnt; j++)
@@ -539,10 +575,10 @@ function PopulateTable(rows_str)
 			}
 			output_str = output_str + "<\/select>\n";
 			
-			output_str = output_str + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='" + JSON_row.URL + "'><\/td>\n";
+			output_str = output_str + "<input type='text' name='URL" + i + "' id='URL" + i + "' value='" + JSON_row.URL + "' onchange=\"SetElementValue('URL" + i + "', -1);\"><\/td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n";
-			output_str = output_str + "<select name='target_select" + i + "' id='target_select" + i + "' onChange='PopulateTarget(" + i + ");'>\n";
+			output_str = output_str + "<select name='target_select" + i + "' id='target_select" + i + "' onChange=\"PopulateTarget(" + i + ");\">\n";
 			if (!JSON_row.target)
 				JSON_row.target = "_self";
 			if (JSON_row.target == "_self")
@@ -559,9 +595,21 @@ function PopulateTable(rows_str)
 				output_str = output_str + "<option value='" + ENTER_FRAME_NAME + "'>" + NAMED_FRAME + "<\/option>\n";
 			output_str = output_str + "<\/select>\n";
 			if ((JSON_row.target == "_blank") || (JSON_row.target == "_self"))
-				output_str = output_str + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "'><\/td>\n";
+				output_str = output_str + "<input type='hidden' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
 			else
 				output_str = output_str + "<input type='text' name='target" + i + "' id='target" + i + "' value='" + JSON_row.target + "' onclick=\"if (this.value == '" + ENTER_FRAME_NAME + "') this.value = '';\"><\/td>\n";
+				
+			output_str = output_str + "<td valign='top'>\n";
+			output_str = output_str + "<select name='mega_menu" + i + "' id='mega_menu" + i + "' onchange=\"SetElementValue(-1, 'mega_menu" + i + "');\">\n";
+			output_str = output_str + "<option value=''>" + _NOT_SELECTED_ + "<\/option>\n";
+			for (var k = 0; k < mega_menu_cnt; k++)
+			{
+				if (mega_menus[k] == JSON_row.mega_menu)
+					output_str = output_str + "<option value='" + mega_menus[k] + "' selected='selected'>" + mega_menus[k] + "<\/option>\n";
+				else
+					output_str = output_str + "<option value='" + mega_menus[k] + "'>" + mega_menus[k] + "<\/option>\n";
+			}
+			output_str = output_str + "<\/select>\n</td>\n";
 			
 			output_str = output_str + "<td valign='top'>\n<input type='hidden' id='sort_order" + i + "' name='sort_order" + i + "' value='" + JSON_row.sort_order + "' />\n";
 			
@@ -878,7 +926,6 @@ function IndentItem(i)
 			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_4TH_SUB_LEVEL;
 		else if (nesting_level == 5)
 			document.getElementById(nesting_level_text_ctl).innerHTML = EDIT_MENU_ITEMS_5TH_SUB_LEVEL;
-			
 	}
 }
 
@@ -923,11 +970,14 @@ function PopulatePage(i)
 {
 	var pageSelect_ctl = "selectPage" + i;
 	var URL_ctl = "URL" + i;
-	var url = document.getElementById(pageSelect_ctl).value + ".php";
+	var url = "";
+	if (document.getElementById(pageSelect_ctl).value != "")
+		url = document.getElementById(pageSelect_ctl).value + ".php";
 	document.getElementById(URL_ctl).value = url;
-	
+
 	window.parent.SetWorkSavedNotSaved(false);
-	return(1);
+
+	SetElementValue(URL_ctl, pageSelect_ctl);
 }
 
 function PopulateTarget(i)
@@ -943,34 +993,92 @@ function PopulateTarget(i)
 		document.getElementById(target_ctl).type = "hidden";
 	
 	window.parent.SetWorkSavedNotSaved(false);
+	
+	SetElementValue(target_ctl, target_select_ctl);
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
-function SetElementValue(el_id)
+function SetElementValue(el_id, el_id_2)
 {
 	var html = document.getElementById("MenuItemsTable").innerHTML;
-	var val = document.getElementById(el_id).value;
-	var srch = "id=\"" + el_id;
-	var pos1 = html.indexOf(srch, 0);
-	if (pos1 == -1)	{
-		srch = "id='" + el_id;
-		pos1 = html.indexOf(srch, 0);
+
+	if (el_id != -1)	{
+		var val = document.getElementById(el_id).value;
+		var srch = "id=\"" + el_id;
+		var pos1 = html.indexOf(srch, 0);
+		if (pos1 == -1)	{
+			srch = "id='" + el_id;
+			pos1 = html.indexOf(srch, 0);
+		}
+		srch = "value=";
+		var pos2 = html.indexOf(srch, pos1);
+		srch = "\"";
+		var pos3 = html.indexOf(srch, pos2);
+		if (pos3 == -1)	{	// In case browser replaced single quotes with double quotes.
+			srch = "'";
+			pos3 = html.indexOf(srch, pos2);
+		}
+		var pos4 = html.indexOf(srch, pos3 + 1);
+		var html_start = html.substr(0, pos2);
+		var html_end = html.substr(pos4 + 1);
+		html = html_start + "value='" + val + "'" + html_end;
 	}
-	srch = "value=";
-	var pos2 = html.indexOf(srch, pos1);
-	srch = "\"";
-	var pos3 = html.indexOf(srch, pos2);
-	if (pos3 == -1)	{
-		srch = "'";
-		pos3 = html.indexOf(srch, pos2);
+
+	if (el_id_2 != -1)	{
+		var val = document.getElementById(el_id_2).value;
+		var srch = "id=\"" + el_id_2;
+		var pos1 = html.indexOf(srch, 0);
+		if (pos1 == -1)	{
+			srch = "id='" + el_id_2;
+			pos1 = html.indexOf(srch, 0);
+		}
+		// Get position of next id to compare in case nothing is selected.
+		srch = "id=";
+		var pos5 = html.indexOf(srch, pos1 + 1);
+		// First remove selected option.
+		srch = "selected="
+		var pos2 = html.indexOf(srch, pos1);
+		if ((pos2 < pos5) && (pos2 > -1))	{	// If not true, then nothing selected.
+			var html_start = html.substr(0, pos2);
+			var html_end = html.substr(pos2 + 19);
+			html = html_start + html_end;
+		}
+		// Now go ahead and insert selected option.
+		srch = "value=\"" + val;
+		pos2 = html.indexOf(srch, pos1);
+		if (pos2 == -1)	{	// In case browser replaced single quotes with double quotes.
+			srch = "value='" + val;
+			pos2 = html.indexOf(srch, pos1);
+		}
+		srch = "\"";
+		var pos3 = html.indexOf(srch, pos2 + 7);
+		if (pos3 == -1)	{
+			srch = "'";
+			pos3 = html.indexOf(srch, pos2);
+		}
+		srch = ">"
+		var pos4 = html.indexOf(srch, pos3);
+		html_start = html.substr(0, pos3 + 1);
+		html_end = html.substr(pos4);
+		html = html_start + " selected='selected'" + html_end;
 	}
-	var pos4 = html.indexOf(srch, pos3 + 1);
-	var html_start = html.substr(0, pos2);
-	var html_end = html.substr(pos4 + 1);
-	html = html_start + "value='" + val + "'" + html_end;
+	
 	document.getElementById("MenuItemsTable").innerHTML = html;
+
+	curr_item_under_edit = "";
 }
 
+function SetElementVal(el_id)
+{
+	if (el_id == curr_item_under_edit)	{
+		SetElementValue(el_id, -1);
+	}
+}
+
+function SetCurrentItem(el_id)
+{
+	curr_item_under_edit = el_id;
+}
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
