@@ -5,6 +5,8 @@
 // Created: 10/19/2014	ELL
 // Modified: 2/23/2015	ELL
 // Added handler for scrolling to keep options div in same position in window.
+// Revised: 4/28/2016	ELL
+// Added ability to use either desktop styles or mobile styles.
 // 
 
 var top_start;
@@ -41,7 +43,7 @@ function OpenHelpWindow()
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#edit_page", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
  
-function SetEditorMode()
+function SetEditorMode(mode)
 {
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
@@ -52,10 +54,10 @@ function SetEditorMode()
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp);
 		
-		if (document.getElementById("editor_mode").checked == true)
-			params = "editor_mode=1";
+		if (document.getElementById(mode).checked == true)
+			params = mode + "=1";
 		else
-			params = "editor_mode=0";
+			params = mode + "=0";
 		
 		xmlhttp.send(params);
 	}
