@@ -5,6 +5,8 @@
 // Created: 11/21/2014	ELL
 // Revised: 21/1/2014	ELL
 // Added edit is source view checkbox.
+// Revised: 5/20/2016	ELL
+// Added ability to use either desktop styles or mobile styles.
 
 window.parent.document.title = document.title;
 
@@ -13,7 +15,7 @@ function OpenHelpWindow()
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_special", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
-function SetEditorMode()
+function SetEditorMode(mode)
 {
 	var xmlhttp;
 	xmlhttp = getXmlHttpRequestObject();
@@ -24,10 +26,10 @@ function SetEditorMode()
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp);
 		
-		if (document.getElementById("editor_mode").checked == true)
-			params = "editor_mode=1";
+		if (document.getElementById(mode).checked == true)
+			params = mode + "=1";
 		else
-			params = "editor_mode=0";
+			params = mode + "=0";
 		
 		xmlhttp.send(params);
 	}
