@@ -9,6 +9,8 @@
 // Added "redirect" to DeleteHead call.
 // Revised: 11/12/2015	ELL
 // Converted from HTML/PHP POST application to AJAX application.
+// Added list of pages to auto-populate suffix for new head content to make creating head content with meaningful names as default behavior,
+// and to allow for automatic assignment at head content creation.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -22,6 +24,13 @@ function OpenHelpWindow()
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_head", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
+function UpdateSuffix(suffix)
+{
+	document.getElementById("suffix").value = suffix;
+	if (suffix == "")
+		GetNextIndex();
+}
+
 function DeleteConfirm()
 {
 	popup_msg.top_offset = 0;
@@ -34,13 +43,13 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteHead(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteHead()
 {
 	var head_name = document.getElementById("head_name_delete").value;
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	$.post( "delete_head.php", { head_name: head_name, redirect: "-no redirect-" } ).done(CompleteDeleteHead) ;
 }
 function CompleteDeleteHead(data)
@@ -206,6 +215,8 @@ function AssignHeadComplete(data)
 	popup_msg.popup_timeout = 3000;
 	if (data_arr[0] > 0)
 		popup_msg.status_msg = "<b>" + data_arr[1] + "</b> " + MANAGE_HEAD_ASSIGNED_1_MSG + " <b>" + data_arr[2] + "</b> " + MANAGE_HEAD_ASSIGNED_2_MSG;
+	else if (data_arr[0] == 0)
+		popup_msg.status_msg = MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR + " <b>" + data_arr[1] + "</b> " + MANAGE_HEAD_ASSIGNED_2_ERR + " <b>" + data_arr[2] + "</b> " + MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR;
 	else
 		popup_msg.status_msg = MANAGE_HEAD_ASSIGNED_1_ERR + " <b>" + data_arr[1] + "</b> " + MANAGE_HEAD_ASSIGNED_2_ERR + " <b>" + data_arr[2] + "</b> " + MANAGE_HEAD_ASSIGNED_3_ERR;
 		
@@ -225,9 +236,22 @@ function PopulateIndex(data)
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function AddHead()
-{
+{	
 	var suffix = document.getElementById("suffix").value;
-	$.post( "add_head.php", { suffix: suffix } ).done(CompleteAddHead) ;
+	var assign_head = 0;
+	if (document.getElementById("suffix").value == document.getElementById("new_head_suffix").value)
+		assign_head = 1;
+	if ((head_names.indexOf("head_" + suffix)) < 0)
+		$.post( "add_head.php", { suffix: suffix, assign_head: assign_head } ).done(CompleteAddHead) ;
+	else	{
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 300;
+		popup_msg.popup_msg_type = 1;
+		popup_msg.popup_timeout = 3000;
+		popup_msg.status_msg = MANAGE_HEAD_PAGE_ALREADY_EXISTS_1_ERR + " <b>head_" + suffix + "</b> " + MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR;
+		popup_msg.ShowPopupMsg();
+		document.getElementById("suffix").className = "highlight";
+	}
 }
 function CompleteAddHead(data)
 {
@@ -248,6 +272,12 @@ function CompleteAddHead(data)
 	GetHeadAssignments();
 }
 
+function ClearHighlight(el)
+{
+	if (el.className == "highlight")
+		el.className = "";
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function RenameHead()
 {
