@@ -8,6 +8,8 @@
 // Revised: 10/28/2014	ELL
 // Added modify user to change access level and revise added fields email, first_name and last_name.
 // Complete overhaul to switch from form posts to AJAX.
+// Revised: 11/20/2017	ELL
+// Changed from admin-only access to limited change password, email and name only access to non admins.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -34,7 +36,7 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteUser(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteUser()
@@ -94,7 +96,8 @@ function rand ( n, m )
 
 function GetUsers()
 {
-	$.post( "get_rows.php", { table: table } ).done(PopulateUsers) ;
+	if (access_level == "admin")
+		$.post( "get_rows.php", { table: table } ).done(PopulateUsers) ;
 }
 function PopulateUsers(data)
 {
@@ -150,12 +153,14 @@ function AddUser()
 	var first_name = document.getElementById('first_name_new_user').value;
 	var last_name = document.getElementById('last_name_new_user').value;
 	
-	$.post( "add_user.php", { user_name: user_name, password: password, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table } ).done(CompleteAddUser) ;
+	$.post( "add_user.php", { user_name: user_name, password: password, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table }, function( data ) { CompleteAddUser(data, user_name) } ) ;
 }
-function CompleteAddUser(data)
+function CompleteAddUser(data, user_name)
 {
 	if (data == "-no data-")
 		popup_msg.status_msg = MANAGE_USERS_USER_NOT_ADDED_ERR;
+	else if (data.indexOf("@@@@@") < 0)
+		popup_msg.status_msg = "<b>" + user_name + "</b> " + CLASSES_ADD_CLASS_ADD_ERR;
 	else
 	{
 		var field_pairs = data.split("@@@@@");
@@ -248,4 +253,38 @@ function CompleteModifyUser(data)
 	if (fields['email'] != "")
 		popup_msg.status_msg = popup_msg.status_msg + " " + MANAGE_USERS_USER_MODIFIED_4_MSG + " <b>" + fields['email'] + "</b>";
 	popup_msg.ShowPopupMsg();
+}
+
+function convertType(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { input.type = 'password'; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
+}
+
+function convertToTxt(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { return elem; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
 }
\ No newline at end of file
