@@ -387,7 +387,8 @@ define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Background
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "Sub Level 1 Background Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "Sub Level 2 Background Color");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Border Color");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Sub Level Block Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "Sub Level 1 Block Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "Sub Level 2 Block Border Color");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Level Item Border Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "Sub Level 1 Item Border Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "Sub Level 2 Item Border Color");
