@@ -355,7 +355,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Level II Text Sub Color")
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Background Colo");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Sub Level Background Colo");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Border Color");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Sub Level Block Border Color");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "Acta Border Color sub Level I");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Item Level Border Color");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Item Level Color sub limite");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T <br> O <br> p");
@@ -1521,4 +1521,5 @@ define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "Tuum style sheet est prima ad
 define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "Sed error fuit exscribend testatem tuum style sheet.");
 define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "fons Type");
 define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "Destination genus non lectus. Select a forum quod genus iterum conare.");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "Level II Acta sub Border Color");
 ?>
\ No newline at end of file
