@@ -355,7 +355,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2级文本颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "顶级背景颜色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等级背景颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最顶层的方块边框颜色");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "分级别阻止边框颜色");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "子级别1块边框颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "顶层项目边框颜色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分层次的项目边框颜色");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
@@ -1521,4 +1521,5 @@ define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "您的样式表已被复制
 define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "复制样式表时出错。");
 define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "来源类型");
 define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地类型未被选中。请选择目的地类型，然后重试。");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子级别2块边框颜色");
 ?>
\ No newline at end of file
