@@ -608,7 +608,7 @@ define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2級文本顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "頂級背景顏色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等級背景顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最頂層的方塊邊框顏色");
-define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "分級別阻止邊框顏色");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BLOCK_BORDER_COLOR', "子級別1塊邊框顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "頂層項目邊框顏色");
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分層次的項目邊框顏色");
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
@@ -2786,4 +2786,5 @@ define('MANAGE_STYLE_SHEET_ATT_COPY_SUCCESS_MSG', "您的樣式表已被複製
 define('MANAGE_STYLE_SHEET_ATT_COPY_ERROR_ERR', "複製樣式表時出錯。");
 define('COPY_STYLE_TO_MOBILE_SOURCE_TYPE', "來源類型");
 define('EDIT_CSS_SELECT_DESTINATION_TYPE_NOT_SELECTED', "目的地類型未被選中。請選擇目的地類型，然後重試。");
+define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BLOCK_BORDER_COLOR', "子級別2塊邊框顏色");
 ?>
\ No newline at end of file
