@@ -631,7 +631,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 						$css_string .= " oblique";
 					if ((in_array('italic', $important) && ($italic == 1)) || (in_array('oblique', $important) && ($oblique == 1)))
 						$css_string .= " !important;\n";
-					else
+					elseif (($italic == 1) || ($oblique == 1))
 						$css_string .= ";\n";
 				}
 				
@@ -648,7 +648,7 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 						$css_string .= " linethrough";
 					if ((in_array('underline', $important) && ($underline == 1)) || (in_array('overline', $important) && ($overline == 1)) || (in_array('blink', $important) && ($blink == 1)) || (in_array('linethrough', $important) && ($linethrough == 1)))
 						$css_string .= " !important;\n";
-					else
+					elseif (($underline == 1) || ($overline == 1) || ($blink == 1) || ($linethrough == 1))
 						$css_string .= ";\n";
 				}
 				elseif ($no_text_decoration == 1)
@@ -727,7 +727,9 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					elseif ($line_height_units == 17)
 						$css_string .= "   line-height: initial";
 						
-					if (in_array('line_height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					if (($line_height != -1) || ($line_height_units == 0) || ($line_height_units > 15))	{
+						if (in_array('line_height', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					}
 				}
 									
 				if ($letter_spacing_units != -1)
@@ -767,7 +769,9 @@ function BuildCSSString($style_sheet, $dbh, $base_dir, $image_dir, $bwb = "", $t
 					elseif ($letter_spacing_units == 15)
 						$css_string .= "   letter-spacing: inherit";
 						
-					if (in_array('letter_spacing', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					if (($letter_spacing != -1000000) || ($letter_spacing_units == 0) || ($letter_spacing_units > 14))	{
+						if (in_array('letter_spacing', $important))	$css_string .= " !important;\n";	else	$css_string .= ";\n";
+					}
 				}		   
 					
 				if ($small_caps == 1)	{
