@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Revised: 4/26/2010	ELL
 // Added dictionary attack protection.
@@ -27,8 +27,21 @@
 	else
 		$redirect_err_to_src = 0;
 
-	include ("../connect/db_connect.php");
-	include ("../connect/config.php");
+	$doc_root = $_SERVER['DOCUMENT_ROOT'];
+	if (file_exists("../connect/config.php"))	// Default installation
+		$connect_path = "../connect/";
+	elseif (file_exists($doc_root . "/connect/config.php"))	// Custom userfile folders
+		$connect_path = $doc_root . "/connect/";
+	else	{	// Must be installeed in sub domain or sub folder with non-standard userfile folders.
+		$php_self = $_SERVER["PHP_SELF"];
+		$self_parts = explode('/', $php_self);
+		$this_script = $self_parts[count($self_parts) - 1];
+		$sub_dir = str_replace(array($doc_root, $this_script), "", $php_self);
+		$sub_dir_parts = explode('/', $sub_dir);
+		$connect_path = $doc_root . '/' . $sub_dir_parts[0] . "/connect/";
+	}
+	include($connect_path . "config.php");
+	include($connect_path . "db_connect.php");
 	include("ignore_fields.php");
 	
 	// If alternate go back specified, then use that if any errors.  This is usefule if sending page session expires if back button is used.
