@@ -28,6 +28,14 @@
 // Fixed bug with users and power users not seeing plugin buttons that don't have access level assigned.
 // Revised: 4/12/2016	ELL
 // Added sub button level to SetPreviousBtnState.
+// Revised: 10/31/2016	ELL
+// Removed "Manage Head Code" from main menu which is now consolidated with "Edit Head Code".  Renamed "Edit Head Code" to "Manage Head Code".
+// "Manage Head Code" now exists as "Manage Custom Head Code" under "Manage Head Code".
+// Added ability to switch CSS menu tools and JS menu tools on or off.
+// Revised: 6/19/2017	ELL
+// Moved 'deployed' field to new table plugins_deployed.
+// Revised: 11/22/2017	ELL
+// Made "Users & Site Options" button modal switchig to "Manage My Account" when logged in as non-admin but at least user access level.
 	
 	include ("check_session.php");
 	
@@ -40,7 +48,7 @@
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$wiz_mode = $row['option_value'];
-	
+
 	if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
 		$website_file_path = "/index.php";
 	elseif (BWB_BASE_DIR == '')
@@ -63,15 +71,15 @@
 	}
 
 	if ($access_level == "blogger")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE (AccessLevel='blogger') AND (deployed=1) ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE (T1.AccessLevel='blogger') AND (T2.deployed=1) ORDER BY T1.sort_order";
 	elseif ($access_level == "restricted")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE ((AccessLevel='blogger') OR (AccessLevel='restricted')) AND (deployed=1) ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted')) AND (T2.deployed=1) ORDER BY T1.sort_order";
 	elseif ($access_level == "user")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE ((AccessLevel='blogger') OR (AccessLevel='restricted') OR (AccessLevel='user') OR (AccessLevel='') OR (AccessLevel IS NULL)) AND (deployed=1) ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='') OR (T1.AccessLevel IS NULL)) AND (T2.deployed=1) ORDER BY T1.sort_order";
 	elseif ($access_level == "power_user")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE ((AccessLevel='blogger') OR (AccessLevel='restricted') OR (AccessLevel='user') OR (AccessLevel='power_user') OR (AccessLevel='') OR (AccessLevel IS NULL)) AND (deployed=1) ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE ((T1.AccessLevel='blogger') OR (T1.AccessLevel='restricted') OR (T1.AccessLevel='user') OR (T1.AccessLevel='power_user') OR (T1.AccessLevel='') OR (T1.AccessLevel IS NULL)) AND (T2.deployed=1) ORDER BY T1.sort_order";
 	elseif ($access_level == "admin")
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE deployed=1 ORDER BY sort_order";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T2.deployed=1 ORDER BY T1.sort_order";
 		
 	$plugin_buttons = array();
 	$plugin_css = array();
@@ -99,7 +107,10 @@
 				$menu_group = "";
 			if (isset($language_folder) && isset($console_link_text_define) && ($console_link_text_define != ""))
 			{
-				include_once ($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php");
+				if (file_exists($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php"))
+					include_once ($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php");
+				else
+					include_once ($document_root . "/" . $language_folder . "/en.php");
 				if (defined($console_link_text_define) && (constant($console_link_text_define) != ""))
 					$console_link_text = constant($console_link_text_define);
 			}
@@ -149,13 +160,13 @@
 	background-attachment:scroll;
 	background-repeat:no-repeat;
 	background-position: 0px 1px;
-	background-image:url(images/help.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/help.png);
 }
 .help_button_main:hover	{
 	background-attachment:scroll;
 	background-repeat:no-repeat;
 	background-position: 0px 1px;
-	background-image:url(images/help_mo.png);
+	background-image:url(theme/<?php echo $theme; ?>/images/help_mo.png);
 	cursor:pointer;
 }
 
@@ -253,7 +264,6 @@ function ResizeWorkspace()
 var access_level = '<?php echo $access_level; ?>';
 var enable_wizard = '<?php echo $enable_wizard; ?>';
 
-
 <?php
 	if (isset($plugin_button_cnt))
 		echo "	var plugin_button_cnt = $plugin_button_cnt;\n";
@@ -321,8 +331,6 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 <div class="button_top_level" id="btn_manage_menu_assignments" title="<?php echo MAIN_MENU_MANAGE_MENUS_BTN; ?>" onClick="SetWorkspaceLocation('manage_menu.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_MANAGE_MENUS_BTN; ?></span></div>
 <div class="button_top_level" id="btn_edit_css_menu_params" title="<?php echo MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN; ?>" onClick="SetWorkspaceLocation('edit_css_menu_params.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN; ?></span></div>
 <div class="button_top_level" id="btn_edit_css_menu_styles" title="<?php echo MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN; ?>" onClick="SetWorkspaceLocation('edit_css_menu_styles.php', this);"><span class="button_text_top_level" ><?php echo MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN; ?></span></div>
-<div class="button_top_level" id="btn_edit_js_menu_params" title="<?php echo MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT; ?>" onClick="SetWorkspaceLocation('edit_js_menu_params.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN; ?></span></div>
-<div class="button_top_level" id="btn_edit_js_menu_styles" title="<?php echo MAIN_MENU_EDIT_JS_MENU_STYLES_BTN_ALT; ?>" onClick="SetWorkspaceLocation('edit_js_menu_styles.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_JS_MENU_STYLES_BTN; ?></span></div>
 <?php
 	if ($plugin_buttons)
 	{
@@ -337,8 +345,7 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 <div id="style_functions">
 <div class="button_heading_top_level" id="btn_heading_style" title="<?php echo MAIN_MENU_STYLES_HEAD_CONTENT_HEADING_ALT; ?>" onClick="ExpandCollapseMenus('style_functions');"><div class="button_heading_text_top_level" style="letter-spacing:-1px"><?php echo MAIN_MENU_STYLES_HEAD_CONTENT_HEADING; ?></div></div>
 <div class="button_top_level" id="btn_edit_styles" title="<?php echo MAIN_MENU_EDIT_STYLES_BTN; ?>" onClick="SetWorkspaceLocation('edit_css_select.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_STYLES_BTN; ?></span></div>
-<div class="button_top_level" id="btn_edit_head_code" title="<?php echo MAIN_MENU_EDIT_HEAD_BTN; ?>" onClick="SetWorkspaceLocation('edit_head_select.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_HEAD_BTN; ?></span></div>
-<div class="button_top_level" id="btn_manage_head_code" title="<?php echo MAIN_MENU_MANAGE_HEAD_BTN; ?>" onClick="SetWorkspaceLocation('manage_head.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_MANAGE_HEAD_BTN; ?></span></div>
+<div class="button_top_level" id="btn_edit_head_code" title="<?php echo MAIN_MENU_MANAGE_HEAD_BTN; ?>" onClick="SetWorkspaceLocation('edit_head_select.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_MANAGE_HEAD_BTN; ?></span></div>
 <div class="button_top_level" id="btn_edit_favicon" title="<?php echo MAIN_MENU_EDIT_FAVICON_BTN; ?>" onClick="SetWorkspaceLocation('edit_favicon.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_EDIT_FAVICON_BTN; ?></span></div>
 <?php
 	if ($plugin_buttons)
@@ -397,8 +404,7 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 				echo "<div class=\"button_top_level\" id=\"btn_show_wizard\" title=\"" . MAIN_MENU_UPLOAD_TEMPLATE_BTN . "\" onClick=\"SetWorkspaceLocation('upload_template_confirm.php', this);\"><span class=\"button_text_top_level\">" . MAIN_MENU_UPLOAD_TEMPLATE_BTN . "</span></div>\n";
 		}
 ?>
-
-<div class="button_top_level" id="btn_users_site_options" title="<?php echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT; ?>" onClick="SetWorkspaceLocation('admin_function_select.php', this);"><span class="button_text_top_level"><?php echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN; ?></span></div>
+<div class="button_top_level" id="btn_users_site_options" title="<?php if ($access_level == "admin") echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT; else echo MAIN_MENU_MANAGE_MY_ACCOUNT_BTN; ?>" onClick="SetWorkspaceLocation('<?php if ($access_level == "admin") echo "admin_function_select.php"; else echo "users.php"; ?>', this);"><span class="button_text_top_level"><?php if ($access_level == "admin") echo MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN; else echo MAIN_MENU_MANAGE_MY_ACCOUNT_BTN; ?></span></div>
 </div>
 <?php } // access_level > restricted and blogger ?>
 </div>
@@ -421,7 +427,7 @@ var enable_wizard = '<?php echo $enable_wizard; ?>';
 <script language="JavaScript"  type="text/javascript">
 //alert(browser + " " + browser_version);
 
-HidePopupMsg();
+popup_msg.HidePopupMsg();
 
 <?php
 if (isset($_GET['module']) && ($_GET['module'] != "") && isset($_GET['btn']) && ($_GET['btn'] != ""))
@@ -431,6 +437,23 @@ if (isset($_GET['module']) && ($_GET['module'] != "") && isset($_GET['btn']) &&
 	echo "var code = \"SetWorkspaceLocation('$module', document.getElementById('$btn'));\";\n";
 	echo "var mTimerSWL = setTimeout(code, 3000);\n";
 }
+
+if (isset($_GET['show_password_reset']) && ($_GET['show_password_reset'] == 1))
+{
+?>
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 300;
+	popup_msg.popup_msg_type = 3;
+	popup_msg.popup_btn_cnt = 2;
+	popup_msg.popup_msg_cell = "<?php echo MAIN_MENU_SHOW_PASSWORD_RESET_MSG; ?>";
+	popup_msg.popup_button_2_span = "<?php echo YES_WORD; ?>";
+	popup_msg.popup_button_1_span = "<?php echo NO_WORD; ?>";
+	popup_msg.popup_timeout = 60000;
+	popup_msg.ShowPopupMsg();
+	document.getElementById("popup_button_2_span").onclick = function () { workspace.location='users.php'; popup_msg.HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { window.location='main.php'; };
+<?php
+}
 ?>
 </script>
 </body>
