@@ -39,4 +39,18 @@
 	
 	if (($curr_session != $session) || ($curr_ip != $ip))
 		header("Location: /index.php");
+		
+	if (defined("BWB_LANG"))
+		include ("../lang/" . BWB_LANG . ".php");
+	else
+		include ("../lang/en.php");
+		
+	$query = "SELECT `option_value` FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name`='Theme'";
+	$result = $bwb_dbh->query($query);
+	if ($result->rowCount() > 0)	{
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		$theme = $row['option_value'];
+	}
+	else
+		$theme = "classic";
 ?>
\ No newline at end of file
