@@ -4,6 +4,9 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 5/29/2012	ELL
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 // 
 // 
 // 
@@ -12,13 +15,12 @@
 	
 	$class = $_POST['class'];
 	$style_sheet = $_POST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 	
 	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
 	$class = str_replace($search, $replace, $class);
 	
-	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class`='" . $class . "'";
+	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '" . $style_sheet . "' AND `class`='" . $class . "'";
 	$result = $bwb_dbh->query($query);
 	
 	if ($result->rowCount() < 1)
