@@ -15,6 +15,7 @@
 	$user_table = $_POST['user_table'];
 	$page = $_POST['page'];
 	$max_rec = $_POST['max_rec'];
+	$user_sort = $_POST['user_sort'];
 	
 	if (!isset($user_table) || ($user_table == ""))
 	{
@@ -27,14 +28,24 @@
 		$max_rec = 50;
 	
 	$_SESSION['last_user_table'] = $user_table;
-		
+	
+	$query = "SELECT * FROM information_schema.COLUMNS WHERE TABLE_SCHEMA = '" . $bwb_database . "' AND TABLE_NAME = '" . $user_table . "' AND COLUMN_NAME = 'UserID'";
+	$result = $bwb_dbh->query($query);
+	if ($result->rowCount() < 1)
+	{
+		echo "-not user access table-";
+		exit;
+	}
+	
 	$start_row = $page * $max_rec;
-	$query = "SELECT * FROM " . $user_table . " ORDER BY `UserID` LIMIT " . $start_row . "," . $max_rec;
+	if (($user_sort != "undefined") && isset($user_sort) && ($user_sort != "") && ($user_sort != "-not set-"))
+		$sort = $user_sort;
+	else
+		$sort = "UserID";
+	$query = "SELECT * FROM " . $user_table . " ORDER BY " . $sort . " LIMIT " . $start_row . "," . $max_rec;
 //	echo $query;
 //	exit;
-
 	$result = $bwb_dbh->query($query);
-	
 	if ($result->rowCount() < 1)
 	{
 		echo "-no data-";
