@@ -6,6 +6,10 @@
 // Created: 10/11/2012	ELL
 // Revised: 12/13/2013	ELL
 // Added refresh of main menu to update buttons and set to last selections.
+// Revised: 6/11/2016	ELL
+// Added simultaneous removal of mobile styles for plugin if they were provided.
+// Revised: 6/19/2017	ELL
+// Moved 'deployed' field to new table plugins_deployed.
 // 
 //
 	include ("check_session.php");
@@ -24,7 +28,7 @@
 	{
 		// Check for other plugins using the same style sheet and deployed.	
 		$skip_remove = false;
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE `style_sheet`='" . $style_sheet . "' AND `id`<>" . $plugin_id;
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id=T2.plugin_id WHERE T1.style_sheet='" . $style_sheet . "' AND T1.id<>" . $plugin_id;
 		$result = $bwb_dbh->query($query);
 		while ($row = $result->fetch(PDO::FETCH_ASSOC))
 		{
@@ -36,20 +40,27 @@
 		{
 			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name`='" . $style_sheet . "'";
 			$cnt = $bwb_dbh->exec($query);
+			
+			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name`='" . $style_sheet . "_mobile'";
+			$cnt = $bwb_dbh->exec($query);
 		
-			// Drop class and CSS tables.
-			$table = $style_sheet . "_classes";
-			$query = "DROP TABLE IF EXISTS " . BWB_TABLE_PREFIX . $table;
+			// Delete classes and CSS from tables.
+			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "site_classes WHERE `style_sheet`='" . $style_sheet . "'";
 			$cnt = $bwb_dbh->exec($query);
 			
-			$table = $style_sheet . "_css";
-			$query = "DROP TABLE IF EXISTS " . BWB_TABLE_PREFIX . $table;
+			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "site_classes WHERE `style_sheet`='" . $style_sheet . "_mobile'";
+			$cnt = $bwb_dbh->exec($query);
+			
+			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "site_css WHERE `style_sheet`='" . $style_sheet . "'";
+			$cnt = $bwb_dbh->exec($query);
+			
+			$query = "DELETE FROM " . BWB_TABLE_PREFIX . "site_css WHERE `style_sheet`='" . $style_sheet . "_mobile'";
 			$cnt = $bwb_dbh->exec($query);
 		}
 	}
 	
 	// Mark plugin as not being deployed.
-	$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=0 WHERE `id`=$plugin_id";
+	$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin_id, `deployed`=0";
 	$cnt = $bwb_dbh->exec($query);
 	
 	$_SESSION['button_group'] = "other_functions";
