@@ -1,7 +1,9 @@
 <?php
-// Reset Password, copyright 2012, EB Dynamics, Inc., Ed Lemmers
+// Reset Password, copyright 2017, Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 11/5/2014	ELL
+// Revised: 11/20/2016	ELL
+// Modified reset password to store temp password in temp users table, then update users table upon logging in with temp password to new temp password.
 //
 //
 session_start();
@@ -93,7 +95,9 @@ $salted_pass = $pass1 . BWB_SALT . $pass2;
 // Encrypt password.
 $encrypt_password = doEncrypt($salted_pass, $UserID);
 // Update user table with new password.
-$query = "UPDATE `" . BWB_TABLE_PREFIX . "users` SET `password`='" . $encrypt_password . "' WHERE `UserID`='" . $UserID . "'";
+$query = "CREATE TABLE IF NOT EXISTS `" . $bwb_database . "`.`" . BWB_TABLE_PREFIX . "tmp_users` ( `UserID` VARCHAR(50) NOT NULL , `password` VARCHAR(255) NOT NULL , `created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP , PRIMARY KEY (`UserID`))";
+$cnt = $bwb_dbh->exec($query);
+$query = "REPLACE INTO `" . BWB_TABLE_PREFIX . "tmp_users` (`password`, `UserID`) VALUES ('" . $encrypt_password . "', '" . $UserID . "')";
 $cnt = $bwb_dbh->exec($query);
 
 
@@ -119,13 +123,13 @@ $protocol_String  = "$protocol://{$domain}{$disp_port}";
 
 if ($html == 1)
 {
-	$msg = "<b>To return to our website,  click here: </b>  " . "<a href=\"" . $protocol_String . "/manage/index.php\">RETURN</a>";
+	$msg = "<b>To return to our website,  click here: </b>  " . "<a href=\"" . $protocol_String . "/manage/index.php?password_reset=1\">RETURN</a>";
 	$msg = "Your user name is <b>" . $UserID  . "</b> and your temporary password is <b>" . $password . "</b>" . $lf . $lf . $msg;
 	$msg = "<b>$subject</b>" . $lf . $msg;
 }
 else
 {
-	$msg = "To return to our website, go to this web address: www." . $protocol_String . "/manage/index.php";
+	$msg = "To return to our website, go to this web address: www." . $protocol_String . "/manage/index.php?password_reset=1";
 	$msg = "Your user name is " . $UserID  . " and your temporary password is " . $password . $lf . $msg;
 	$msg = $subject . $lf . $msg;
 }
@@ -142,7 +146,7 @@ $mail->no_mime = $no_mime;
 $mail->send();
 
 // Go to desired next page.
-header("Location: index.php?err=password_reset");
+header("Location: index.php?err=password_reset&password_reset=1");
 exit;
 
 /////////////////////////////////////////////////////////////////////////
@@ -174,7 +178,7 @@ function check_referer($referers)
 					$found = true;
 			}
 			if (!$found) {
-				$errors[] = '1|You are coming from an unauthorized domain.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+				$errors[] = '1|You are coming from an unauthorized domain.';
 				error_log('[PHPFormMail] Illegal Referer. (' . getenv('HTTP_REFERER') . ')', 0);
 			}
 			return $found;
@@ -184,7 +188,7 @@ function check_referer($referers)
 			return false;
 		}
 	} else {
-		$errors[] = '1|There are no referers defined.  All submissions will be denied.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+		$errors[] = '1|There are no referers defined.  All submissions will be denied';
 		error_log('[PHPFormMail] You have no referers defined.  All submissions will be denied.', 0);
 		return false;
 	}
