@@ -203,7 +203,7 @@ while ($row = $result->fetch(PDO::FETCH_ASSOC))
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 </script>
 </body>
 </html>
