@@ -17,12 +17,15 @@
 	
 	// Open SQL file and read in all lines.
 	$document_root = getenv('DOCUMENT_ROOT');
+	if (!isset($tmp_folder) || ($tmp_folder == ""))
+		$tmp_folder = "tmp";
+	
 	if (isset($sql_file) && ($sql_file != ""))	// If installing plugin or some other SQL file, then use that file.
 	{
 		$sql_file_parts = explode(".", $sql_file);
 		$sql_file_name = $sql_file_parts[0];
 		echo READING_WORD . " $sql_file_name " . UPLOAD_TEMPLATE_SQL_FILE_MSG . "<br><br>\n";
-		$sql_file = $document_root . "/tmp/" . $sql_file;
+		$sql_file = $document_root . "/" . $tmp_folder . "/" . $sql_file;
 	}
 	else
 	{
@@ -40,7 +43,7 @@
 	
 	echo PARSING_WORD . " $sql_file_name " . UPLOAD_TEMPLATE_SQL_MSG . "<br><br>\n";
 	
-	include("lib/run_sql.php");
+	include_once("lib/run_sql.php");
 	
 	$result = RunSQL($sql_string, $bwb_dbh, BWB_TABLE_PREFIX, false, true, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 ?>
\ No newline at end of file
