@@ -460,7 +460,7 @@ if ($disable_site_styles != 1)
 			}
 			$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='" . $page_name . "'";
 			$result = $bwb_dbh->query($query);
-			if ($result->rowCount() < -1)
+			if ($result->rowCount() < 1)
 			{
 				echo "ERROR: Can't find page content for page $pagename.<br/>";
 				$page_content_append = "";
@@ -484,13 +484,13 @@ if ($disable_site_styles != 1)
 				if (strpos($page_content_append, $post_locate_string) !== false)
 				{
 					$page_content_arr = explode($post_locate_string, $page_content_append);
-					$page_content_w_blog = $page_content_prepend . $page_content_arr[0] . $sValue . $page_content_arr[2]; 
+					$page_content_w_blog = $page_content_prepend . $blog_encap_delim . $page_content_arr[0] . $sValue . $page_content_arr[2]; 
 				}
 				else
-					$page_content_w_blog = $page_content_prepend . $sValue . $page_content_append;
+					$page_content_w_blog = $page_content_prepend . $blog_encap_delim . $sValue . $page_content_append;
 			}
 			else
-				$page_content_w_blog = $page_content_prepend . $sValue . $page_content_append;	// Prepend page with new post and publish.
+				$page_content_w_blog = $page_content_prepend . $blog_encap_delim . $sValue . $page_content_append;	// Prepend page with new post and publish.
 			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET page_content='$page_content_w_blog', revised='$today' WHERE page_name='$page_name'";	
 		}
 		else
