@@ -12,6 +12,9 @@
 // Added table prefix handling.
 // Revised: 3/11/2016	ELL
 // Added regeneration of CSS file such that sort order takes effect immediately.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 // 
 // 
 // 
@@ -19,10 +22,9 @@
 	include ("check_session.php");
 		
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 	
 	$i = 0;
-	$query_tags = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` ORDER BY `sort_order`";
+	$query_tags = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' ORDER BY `sort_order`";
 	$result_tags = $bwb_dbh->query($query_tags);
 	while ($row_tags = $result_tags->fetch(PDO::FETCH_ASSOC))
 	{
@@ -36,7 +38,7 @@
 			$sort_order = 0;
 			
 		//Insert new data into table.
-		$query = "UPDATE `" . BWB_TABLE_PREFIX . $class_table . "` SET `sort_order` = " . $sort_order . " WHERE `class` = '" . $class . "'";
+		$query = "UPDATE `" . BWB_TABLE_PREFIX . "site_classes` SET `sort_order` = " . $sort_order . " WHERE `style_sheet` = '$style_sheet' AND `class` = '" . $class . "'";
 		$cnt = $bwb_dbh->exec($query);
 				
 		$i++;
@@ -46,9 +48,8 @@
 	// Build string for css file and re-write file /////
 	include("lib/build_css_string.php");
 
-	$css_table = $style_sheet . "_css";
 	$css_file = $style_sheet . ".css";
-	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
+	$css_string = BuildCSSString($style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
 
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
 	if (BWB_BASE_DIR == '')
