@@ -4,12 +4,17 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created:	10/19/2014	ELL
+// Rezised: 4/28/2016	ELL
+// Added ability to use either desktop styles or mobile styles.
 
 include ("check_session.php");
 
 if (isset($_REQUEST['editor_mode']))
 	$_SESSION['editor_mode'] = $_REQUEST['editor_mode'];
 	
+if (isset($_REQUEST['style_mode']))
+	$_SESSION['style_mode'] = $_REQUEST['style_mode'];
+	
 if (isset($_REQUEST['site_styles']) && ($_REQUEST['site_styles'] != -1))
 	$_SESSION['site_styles'] = $_REQUEST['site_styles'];
 ?>
\ No newline at end of file
