@@ -4,13 +4,15 @@
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 8/27/2014	ELL
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 
 	include ("check_session.php");
 	
 	$goto_class = $_REQUEST['goto_class'];
 	$sort_alpha = $_REQUEST['sort_alpha'];
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 	
 	$_SESSION['class_sort_method'] = $sort_alpha;
 
@@ -21,9 +23,9 @@
 	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$goto_class_cmp = str_replace($search, $replace, $goto_class);
 	if ($sort_alpha == 1)
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` ORDER BY `class`";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' ORDER BY `class`";
 	else
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` ORDER BY `sort_order`";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' ORDER BY `sort_order`";
 		
 	$result = $bwb_dbh->query($query);
 	while ($row = $result->fetch(PDO::FETCH_ASSOC))
