@@ -8,6 +8,10 @@
 // Added table prefix handling.
 // Revised: 5/14/2013	ELL
 // Added URL escaping and unescaping of URL itself.
+// Revised: 10/25/2016	ELL
+// Added handling of mega menus.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
 // 
 //
 //
@@ -18,10 +22,6 @@
 	$menu = $_POST['menu'];
 
 	// Build item arrays from POST variables.
-	$suffix = substr($menu, 4);
-	$menu_items_table = "menu"  . $suffix . "_items";
-	
-	
 	$ID = $_POST["ID"];
 	$item_text = $_POST['item_text'];
 	$item_text = trim(UnescapeURL($item_text));
@@ -29,6 +29,7 @@
 	$URL = $_POST["URL"];
 	$URL = trim(UnescapeURL($URL));
 	$target = $_POST["target"];
+	$mega_menu = $_POST["mega_menu"];
 	$sort_order = $_POST["sort_order"];
 		
 	//Insert new data into table.
@@ -38,17 +39,9 @@
 	$URL = addslashes($URL);
 	$target = addslashes($target);
 		
-	$query = "UPDATE " . BWB_TABLE_PREFIX . $menu_items_table . " SET item_text='" . $item_text . "', level='" . $level . "', URL='" . $URL . "', target ='" . $target . "', sort_order=" . $sort_order . " WHERE ID=" . $ID;
+	$query = "UPDATE " . BWB_TABLE_PREFIX . "menu_items SET item_text='" . $item_text . "', level='" . $level . "', URL='" . $URL . "', target='" . $target . "', mega_menu='" . $mega_menu . "', sort_order=" . $sort_order . " WHERE menu='" . $menu . " ' AND ID=" . $ID;
 		$cnt = $bwb_dbh->exec($query);
 	
-	////////////////////////////////////////////////////////////
-	// Re-write menu_items.js with new references.
-	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus WHERE menu_name = '$menu'";
-	$result = $bwb_dbh->query($query);
-	$row = $row = $result->fetch(PDO::FETCH_ASSOC);
-	$menu_type = $row['menu_type'];
-	if ($menu_type == 1)
-		include("save_menu_items_file.php");
 	// Re-write sitemap.xml for web crawlers.
 	include("generate_site_map.php");
 	
