@@ -6,7 +6,8 @@
 // Created: 6/30/2012	ELL
 // Revised: 8/3/2014	ELL
 // Added Show Login Links Always checkboxes.
-// 
+// Revised: 3/24/2016	ELL
+// Added auto-addition of missing fields.
 // 
 //
 //
@@ -22,9 +23,13 @@
 	$access_level = $_POST["access_level"];
 	$login_page = $_POST["login_page"];
 	$show_login_links = $_POST["show_login_links"];
+	$add_missing_fields = $_POST["add_missing_fields"];
 		
 	$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data SET login_required=" . $login_required . ", user_table='" . $user_table . "', AccessLevel='" . $access_level . "', login_page='" . $login_page . "', show_login_links=" . $show_login_links . " WHERE page_name='" . $page_name . "'";
 	$cnt = $bwb_dbh->exec($query);
 	
+	if ($add_missing_fields == 1)
+		include("add_login_fields.php");
+	
 	echo "Update complete";
 ?>
