@@ -10,7 +10,7 @@
 //
 
 include ("check_session.php");
-include("../php/mime_mail.inc");
+include("../" . BWB_LIB_DIR . "/mime_mail.inc");
 
 $UserID = $_POST['UserID'];
 if ($_POST["Active"] == "true")
